@@ -1,6 +1,6 @@
 /* gnome-db-browser.c
  *
- * Copyright (C) 2006 Vivien Malerba
+ * Copyright (C) 2006 - 2007 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -441,7 +441,7 @@ sql_console_cb (GtkWidget *wid, BrowserConfig *config)
 	GtkWidget *dlg, *sw, *console;
 
         /* dialog */
-        dlg = gtk_dialog_new_with_buttons (_("SQL console"), NULL, 0,
+        dlg = gtk_dialog_new_with_buttons (_("SQL Console"), NULL, 0,
                                            GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
         gtk_dialog_set_has_separator (GTK_DIALOG (dlg), FALSE);
         gtk_window_set_title (GTK_WINDOW (dlg), _("SQL Console"));
@@ -547,6 +547,7 @@ build_data_types_page (BrowserConfig *config)
 	gtk_box_pack_start (GTK_BOX (vb), sw, TRUE, TRUE, 0);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC,
 					GTK_POLICY_AUTOMATIC);
+        gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_IN);
 	textview = gtk_text_view_new ();
 	gtk_container_add (GTK_CONTAINER (sw), textview);
 	gtk_text_view_set_left_margin (GTK_TEXT_VIEW (textview), 5);
@@ -780,6 +781,7 @@ build_tables_views_page (BrowserConfig *config)
 	gtk_box_pack_start (GTK_BOX (vb), sw, TRUE, TRUE, 0);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC,
 					GTK_POLICY_AUTOMATIC);
+        gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_IN);
 	textview = gtk_text_view_new ();
 	gtk_container_add (GTK_CONTAINER (sw), textview);
 	gtk_text_view_set_left_margin (GTK_TEXT_VIEW (textview), 5);
@@ -1078,24 +1080,24 @@ table_view_contents (GtkWidget *button, BrowserConfig *config)
 		/* print modification queries */
 		g_object_get (G_OBJECT (query_model), "insert_query", &query, NULL);
 		if (query) {
-			str = gda_renderer_render_as_sql (GDA_RENDERER (query), NULL, 
-							  GDA_RENDERER_EXTRA_VAL_ATTRS, NULL);
+			str = gda_renderer_render_as_sql (GDA_RENDERER (query), NULL, NULL,
+							  GDA_RENDERER_PARAMS_AS_DETAILED, NULL);
 			g_print("===> SQL insert is %s \n", str);
 			g_free (str);
 			g_object_unref (query);
 		}
 		g_object_get (G_OBJECT (query_model), "update_query", &query, NULL);
 		if (query) {
-			str = gda_renderer_render_as_sql (GDA_RENDERER (query), NULL, 
-							  GDA_RENDERER_EXTRA_VAL_ATTRS, NULL);
+			str = gda_renderer_render_as_sql (GDA_RENDERER (query), NULL, NULL,
+							  GDA_RENDERER_PARAMS_AS_DETAILED, NULL);
 			g_print("===> SQL update is %s \n", str);
 			g_free (str);
 			g_object_unref (query);
 		}
 		g_object_get (G_OBJECT (query_model), "delete_query", &query, NULL);
 		if (query) {
-			str = gda_renderer_render_as_sql (GDA_RENDERER (query), NULL, 
-							  GDA_RENDERER_EXTRA_VAL_ATTRS, NULL);
+			str = gda_renderer_render_as_sql (GDA_RENDERER (query), NULL, NULL,
+							  GDA_RENDERER_PARAMS_AS_DETAILED, NULL);
 			g_print("===> SQL delete is %s \n", str);
 			g_free (str);
 			g_object_unref (query);
