@@ -32,9 +32,10 @@ static void gnome_db_entry_boolean_finalize (GObject   * object);
 static GtkWidget *create_entry (GnomeDbEntryWrapper *mgwrap);
 static void       real_set_value (GnomeDbEntryWrapper *mgwrap, const GValue *value);
 static GValue    *real_get_value (GnomeDbEntryWrapper *mgwrap);
-static void       connect_signals(GnomeDbEntryWrapper *mgwrap, GCallback callback);
+static void       connect_signals(GnomeDbEntryWrapper *mgwrap, GCallback modif_cb, GCallback activ_cb);
 static gboolean   expand_in_layout (GnomeDbEntryWrapper *mgwrap);
 static void       set_editable (GnomeDbEntryWrapper *mgwrap, gboolean editable);
+static void       grab_focus (GnomeDbEntryWrapper *mgwrap);
 
 /* get a pointer to the parents to be able to call their destructor */
 static GObjectClass  *parent_class = NULL;
@@ -86,6 +87,7 @@ gnome_db_entry_boolean_class_init (GnomeDbEntryBooleanClass * class)
 	GNOME_DB_ENTRY_WRAPPER_CLASS (class)->connect_signals = connect_signals;
 	GNOME_DB_ENTRY_WRAPPER_CLASS (class)->expand_in_layout = expand_in_layout;
 	GNOME_DB_ENTRY_WRAPPER_CLASS (class)->set_editable = set_editable;
+	GNOME_DB_ENTRY_WRAPPER_CLASS (class)->grab_focus = grab_focus;
 }
 
 static void
@@ -232,7 +234,7 @@ real_get_value (GnomeDbEntryWrapper *mgwrap)
 
 static void check_toggled_cb (GtkToggleButton *toggle, GnomeDbEntryBoolean *mgbool);
 static void
-connect_signals(GnomeDbEntryWrapper *mgwrap, GCallback callback)
+connect_signals(GnomeDbEntryWrapper *mgwrap, GCallback modif_cb, GCallback activ_cb)
 {
 	GnomeDbEntryBoolean *mgbool;
 
@@ -241,7 +243,9 @@ connect_signals(GnomeDbEntryWrapper *mgwrap, GCallback callback)
 	g_return_if_fail (mgbool->priv);
 
 	g_signal_connect (G_OBJECT (mgbool->priv->check), "toggled",
-			  callback, mgwrap);
+			  modif_cb, mgwrap);
+	g_signal_connect (G_OBJECT (mgbool->priv->check), "toggled",
+			  activ_cb, mgwrap);
 	g_signal_connect (G_OBJECT (mgbool->priv->check), "toggled",
                           G_CALLBACK (check_toggled_cb), mgwrap);
 }
@@ -269,3 +273,15 @@ set_editable (GnomeDbEntryWrapper *mgwrap, gboolean editable)
 
 	gtk_widget_set_sensitive (mgbool->priv->check, editable);
 }
+
+static void
+grab_focus (GnomeDbEntryWrapper *mgwrap)
+{
+	GnomeDbEntryBoolean *mgbool;
+
+	g_return_if_fail (GNOME_DB_IS_ENTRY_BOOLEAN (mgwrap));
+	mgbool = GNOME_DB_ENTRY_BOOLEAN (mgwrap);
+	g_return_if_fail (mgbool->priv);
+
+	gtk_widget_grab_focus (mgbool->priv->check);
+}
