@@ -18,11 +18,15 @@
  * USA
  */
 
+#include <glib/gi18n-lib.h>
+#include <string.h>
 #include "gnome-db-entry-string.h"
 #include <libgda/gda-data-handler.h>
 #include "gdk/gdkkeysyms.h"
 #include <pango/pango.h>
 
+#define MAX_ACCEPTED_STRING_LENGTH 500
+
 /* 
  * Main static functions 
  */
@@ -56,9 +60,10 @@ static void gnome_db_entry_string_start_editing (GtkCellEditable *iface, GdkEven
 static GtkWidget *create_entry (GnomeDbEntryWrapper *mgwrap);
 static void       real_set_value (GnomeDbEntryWrapper *mgwrap, const GValue *value);
 static GValue    *real_get_value (GnomeDbEntryWrapper *mgwrap);
-static void       connect_signals(GnomeDbEntryWrapper *mgwrap, GCallback callback);
+static void       connect_signals(GnomeDbEntryWrapper *mgwrap, GCallback modif_cb, GCallback activ_cb);
 static gboolean   expand_in_layout (GnomeDbEntryWrapper *mgwrap);
 static void       set_editable (GnomeDbEntryWrapper *mgwrap, gboolean editable);
+static void       grab_focus (GnomeDbEntryWrapper *mgwrap);
 
 /* get a pointer to the parents to be able to call their destructor */
 static GObjectClass  *parent_class = NULL;
@@ -128,6 +133,7 @@ gnome_db_entry_string_class_init (GnomeDbEntryStringClass * class)
 	GNOME_DB_ENTRY_WRAPPER_CLASS (class)->connect_signals = connect_signals;
 	GNOME_DB_ENTRY_WRAPPER_CLASS (class)->expand_in_layout = expand_in_layout;
 	GNOME_DB_ENTRY_WRAPPER_CLASS (class)->set_editable = set_editable;
+	GNOME_DB_ENTRY_WRAPPER_CLASS (class)->grab_focus = grab_focus;
 
 	/* Properties */
 	object_class->set_property = gnome_db_entry_string_set_property;
@@ -169,7 +175,7 @@ gnome_db_entry_string_new (GdaDataHandler *dh, GType type)
 
 	g_return_val_if_fail (GDA_IS_DATA_HANDLER (dh), NULL);
 	g_return_val_if_fail (type != G_TYPE_INVALID, NULL);
-	g_return_val_if_fail (gda_data_handler_accepts_gda_type (dh, type), NULL);
+	g_return_val_if_fail (gda_data_handler_accepts_g_type (dh, type), NULL);
 
 	obj = g_object_new (GNOME_DB_TYPE_ENTRY_STRING, "handler", dh, NULL);
 	mgstr = GNOME_DB_ENTRY_STRING (obj);
@@ -356,6 +362,15 @@ real_set_value (GnomeDbEntryWrapper *mgwrap, const GValue *value)
 
 			str = gda_data_handler_get_str_from_value (dh, value);
 			if (str) {
+				if (strlen (str) > MAX_ACCEPTED_STRING_LENGTH) {
+					gchar *msg;
+					gint len;
+					msg = _("<string cut because too long>");
+					len = strlen (msg);
+					str [MAX_ACCEPTED_STRING_LENGTH] = 0;
+					memmove (str + len, str, MAX_ACCEPTED_STRING_LENGTH - len);
+					memcpy (str, msg, strlen (msg));
+				}
 				gtk_entry_set_text (GTK_ENTRY (mgstr->priv->entry), str);
 				g_free (str);
 			}
@@ -421,19 +436,41 @@ real_get_value (GnomeDbEntryWrapper *mgwrap)
 	return value;
 }
 
+typedef void (*Callback2) (gpointer, gpointer);
+static gboolean
+focus_out_cb (GtkWidget *widget, GdkEventFocus *event, GnomeDbEntryString *mgstr)
+{
+	GCallback activ_cb;
+	activ_cb = g_object_get_data (G_OBJECT (widget), "_activ_cb");
+	g_assert (activ_cb);
+	((Callback2)activ_cb) (widget, mgstr);
+
+	return FALSE;
+}
+
 static void
-connect_signals(GnomeDbEntryWrapper *mgwrap, GCallback callback)
+connect_signals(GnomeDbEntryWrapper *mgwrap, GCallback modif_cb, GCallback activ_cb)
 {
 	GnomeDbEntryString *mgstr;
 
 	g_return_if_fail (GNOME_DB_IS_ENTRY_STRING (mgwrap));
 	mgstr = GNOME_DB_ENTRY_STRING (mgwrap);
 	g_return_if_fail (mgstr->priv);
+	g_object_set_data (G_OBJECT (mgstr->priv->entry), "_activ_cb", activ_cb);
+	g_object_set_data (G_OBJECT (mgstr->priv->view), "_activ_cb", activ_cb);
 
 	g_signal_connect (G_OBJECT (mgstr->priv->entry), "changed",
-			  callback, mgwrap);
+			  modif_cb, mgwrap);
+	g_signal_connect (G_OBJECT (mgstr->priv->entry), "activate",
+			  activ_cb, mgwrap);
+	g_signal_connect (G_OBJECT (mgstr->priv->entry), "focus-out-event",
+			  G_CALLBACK (focus_out_cb), mgstr);
+
 	g_signal_connect (G_OBJECT (mgstr->priv->buffer), "changed",
-			  callback, mgwrap);
+			  modif_cb, mgwrap);
+	g_signal_connect (G_OBJECT (mgstr->priv->view), "focus-out-event",
+			  G_CALLBACK (focus_out_cb), mgstr);
+	/* FIXME: how does the user "activates" the GtkTextView widget ? */
 }
 
 static gboolean
@@ -461,6 +498,21 @@ set_editable (GnomeDbEntryWrapper *mgwrap, gboolean editable)
 	gtk_text_view_set_editable (GTK_TEXT_VIEW (mgstr->priv->view), editable);
 }
 
+static void
+grab_focus (GnomeDbEntryWrapper *mgwrap)
+{
+	GnomeDbEntryString *mgstr;
+
+	g_return_if_fail (GNOME_DB_IS_ENTRY_STRING (mgwrap));
+	mgstr = GNOME_DB_ENTRY_STRING (mgwrap);
+	g_return_if_fail (mgstr->priv);
+
+	if (mgstr->priv->multiline)
+		gtk_widget_grab_focus (mgstr->priv->view);
+	else
+		gtk_widget_grab_focus (mgstr->priv->entry);
+}
+
 /*
  * GtkCellEditable interface
  */
