@@ -55,17 +55,19 @@ struct _GnomeDbEntryWrapperClass
 	GtkWidget        *(*create_entry)     (GnomeDbEntryWrapper *mgwrp);
 	void              (*real_set_value)   (GnomeDbEntryWrapper *mgwrp, const GValue *value);
 	GValue           *(*real_get_value)   (GnomeDbEntryWrapper *mgwrp);
-	void              (*connect_signals)  (GnomeDbEntryWrapper *mgwrp, GCallback callback);
+	void              (*connect_signals)  (GnomeDbEntryWrapper *mgwrp, GCallback modif_cb, GCallback activ_cb);
 	gboolean          (*expand_in_layout) (GnomeDbEntryWrapper *mgwrp);
 	void              (*set_editable)     (GnomeDbEntryWrapper *mgwrp, gboolean editable);
 
 	gboolean          (*value_is_equal_to)(GnomeDbEntryWrapper *mgwrp, const GValue *value);
 	gboolean          (*value_is_null)    (GnomeDbEntryWrapper *mgwrp);
+	void              (*grab_focus)       (GnomeDbEntryWrapper *mgwrp);
 };
 
 
-GType           gnome_db_entry_wrapper_get_type         (void);
-void            gnome_db_entry_wrapper_contents_changed (GnomeDbEntryWrapper *mgwrp);
+GType           gnome_db_entry_wrapper_get_type           (void);
+void            gnome_db_entry_wrapper_contents_changed   (GnomeDbEntryWrapper *mgwrp);
+void            gnome_db_entry_wrapper_contents_activated (GnomeDbEntryWrapper *mgwrp);
 
 G_END_DECLS
 
