@@ -34,7 +34,7 @@ static void gnome_db_entry_filesel_finalize (GObject   * object);
 static GtkWidget *create_entry (GnomeDbEntryWrapper *mgwrap);
 static void       real_set_value (GnomeDbEntryWrapper *mgwrap, const GValue *value);
 static GValue    *real_get_value (GnomeDbEntryWrapper *mgwrap);
-static void       connect_signals(GnomeDbEntryWrapper *mgwrap, GCallback callback);
+static void       connect_signals(GnomeDbEntryWrapper *mgwrap, GCallback modif_cb, GCallback activ_cb);
 static gboolean   expand_in_layout (GnomeDbEntryWrapper *mgwrap);
 static void       set_editable (GnomeDbEntryWrapper *mgwrap, gboolean editable);
 
@@ -298,7 +298,7 @@ real_get_value (GnomeDbEntryWrapper *mgwrap)
 }
 
 static void
-connect_signals(GnomeDbEntryWrapper *mgwrap, GCallback callback)
+connect_signals(GnomeDbEntryWrapper *mgwrap, GCallback modif_cb, GCallback activ_cb)
 {
 	GnomeDbEntryFilesel *filesel;
 
@@ -307,7 +307,9 @@ connect_signals(GnomeDbEntryWrapper *mgwrap, GCallback callback)
 	g_return_if_fail (filesel->priv);
 
 	g_signal_connect (G_OBJECT (filesel->priv->entry), "changed",
-			  callback, mgwrap);
+			  modif_cb, mgwrap);
+	g_signal_connect (G_OBJECT (filesel->priv->entry), "activate",
+			  activ_cb, mgwrap);
 }
 
 static gboolean
