@@ -30,7 +30,7 @@ G_BEGIN_DECLS
 #define GNOME_DB_TYPE_BASIC_FORM          (gnome_db_basic_form_get_type())
 #define GNOME_DB_BASIC_FORM(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_basic_form_get_type(), GnomeDbBasicForm)
 #define GNOME_DB_BASIC_FORM_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_basic_form_get_type (), GnomeDbBasicFormClass)
-#define IS_GNOME_DB_BASIC_FORM(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_basic_form_get_type ())
+#define GNOME_DB_IS_BASIC_FORM(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_basic_form_get_type ())
 
 typedef struct {
 	GladeXML *xml_object; /* one of xml_object or */
@@ -59,6 +59,7 @@ struct _GnomeDbBasicFormClass
 
 	/* signals */
         void       (*param_changed)         (GnomeDbBasicForm *form, GdaParameter *param, gboolean is_user_modif);
+	void       (*activated)             (GnomeDbBasicForm *form);
 };
 
 /* 
@@ -76,17 +77,20 @@ gboolean          gnome_db_basic_form_has_been_changed         (GnomeDbBasicForm
 void              gnome_db_basic_form_reset                    (GnomeDbBasicForm *form);
 void              gnome_db_basic_form_set_current_as_orig      (GnomeDbBasicForm *form);
 
-void              gnome_db_basic_form_show_entries_actions     (GnomeDbBasicForm *form, gboolean show_actions);
+void              gnome_db_basic_form_show_entry_actions     (GnomeDbBasicForm *form, gboolean show_actions);
 void              gnome_db_basic_form_entry_show               (GnomeDbBasicForm *form, 
 								GdaParameter *param, gboolean show);
-void              gnome_db_basic_form_entry_set_sensitive      (GnomeDbBasicForm *form, GdaParameter *param, 
+void              gnome_db_basic_form_entry_grab_focus         (GnomeDbBasicForm *form, GdaParameter *param);
+void              gnome_db_basic_form_entry_set_editable       (GnomeDbBasicForm *form, GdaParameter *param, 
 								gboolean sensitive);
 void              gnome_db_basic_form_set_entries_auto_default (GnomeDbBasicForm *form, gboolean auto_default);
 void              gnome_db_basic_form_set_entries_default      (GnomeDbBasicForm *form);
 
+GtkWidget        *gnome_db_basic_form_get_entry_widget         (GnomeDbBasicForm *form, GdaParameter *param);
+GtkWidget        *gnome_db_basic_form_get_label_widget         (GnomeDbBasicForm *form, GdaParameter *param);
+
+void              gnome_db_basic_form_entry_set_editable       (GnomeDbBasicForm *form, GdaParameter *param, gboolean editable);
+
 G_END_DECLS
 
 #endif
-
-
-
