@@ -1,6 +1,6 @@
 /* GNOME DB library
  *
- * Copyright (C) 1999 - 2005 The Free Software Foundation
+ * Copyright (C) 1999 - 2006 The Free Software Foundation
  *
  * AUTHORS:
  *      Rodrigo Moya <rodrigo@gnome-db.org>
@@ -23,17 +23,15 @@
  */
 
 #include <string.h>
+#include <glib/gi18n-lib.h>
+#include <gtk/gtkcelllayout.h>
 #include "gnome-db-combo.h"
-#include "gnome-db-model-wrapper.h"
-#include "gnome-db-data-proxy.h"
-#include "gnome-db-entity.h"
-#include "gnome-db-field.h"
-#include "gnome-db-server-data-type.h"
-#include "gnome-db-data-handler.h"
+#include "gnome-db-data-store.h"
+#include <gtk/gtk.h>
 
 struct _GnomeDbComboPrivate {
-	GnomeDbDataModel *model;
-	GnomeDbDataProxy *proxy;
+	GdaDataModel     *model; /* proxied model (the one when _set_model() is called) */
+	GnomeDbDataStore *store; /* model proxy */
 
 	/* columns of the model to display */
 	gint              n_cols;
@@ -59,6 +57,7 @@ enum {
 	PROP_MODEL
 };
 
+/* get a pointer to the parents to be able to call their destructor */
 static GObjectClass *parent_class = NULL;
 
 /*
@@ -101,7 +100,8 @@ gnome_db_combo_class_init (GnomeDbComboClass *klass)
 
 	/* add class properties */
 	g_object_class_install_property (object_class, PROP_MODEL,
-					 g_param_spec_object ("model", NULL, NULL, GDA_TYPE_DATA_MODEL,
+					 g_param_spec_object ("model", _("The data model to display"), NULL, 
+							      GDA_TYPE_DATA_MODEL,
 							      (G_PARAM_READABLE | G_PARAM_WRITABLE)));
 }
 
@@ -113,7 +113,7 @@ gnome_db_combo_init (GnomeDbCombo *combo, GnomeDbComboClass *klass)
 	/* allocate private structure */
 	combo->priv = g_new0 (GnomeDbComboPrivate, 1);
 	combo->priv->model = NULL;
-	combo->priv->proxy = NULL;
+	combo->priv->store = NULL;
 
 	gtk_combo_box_set_wrap_width (GTK_COMBO_BOX (combo), 0);
 }
@@ -160,6 +160,24 @@ gnome_db_combo_get_property (GObject *object,
 	}
 }
 
+static void
+model_changed_cb (GdaDataModel *model, GnomeDbCombo *combo)
+{
+	gtk_combo_box_set_active (GTK_COMBO_BOX (combo), -1);
+}
+
+static void
+model_destroyed_cb (GdaDataModel *model, GnomeDbCombo *combo)
+{
+	g_assert (model == combo->priv->model);
+	g_signal_handlers_disconnect_by_func (model,
+					      G_CALLBACK (model_destroyed_cb), combo);
+	g_signal_handlers_disconnect_by_func (model,
+					      G_CALLBACK (model_changed_cb), combo);
+	g_object_unref (model);
+	combo->priv->model = NULL;
+}
+
 static void
 gnome_db_combo_dispose (GObject *object)
 {
@@ -168,14 +186,11 @@ gnome_db_combo_dispose (GObject *object)
 	g_return_if_fail (GNOME_DB_IS_COMBO (combo));
 
 	/* free objects references */
-	if (combo->priv->model) {
-		g_object_unref (G_OBJECT (combo->priv->model));
-		combo->priv->model = NULL;
-	}
-
-	if (combo->priv->proxy) {
-		g_object_unref (G_OBJECT (combo->priv->proxy));
-		combo->priv->proxy = NULL;
+	if (combo->priv->model) 
+		model_destroyed_cb (combo->priv->model, combo);
+	if (combo->priv->store) {
+		g_object_unref (G_OBJECT (combo->priv->store));
+		combo->priv->store = NULL;
 	}
 
 	/* chain to parent class */
@@ -223,7 +238,8 @@ gnome_db_combo_new ()
  * @n_cols: number of columns in the model to be shown
  * @cols_index: index of each column to be shown
  *
- * Create a new GnomeDbCombo widget with a model.
+ * Create a new GnomeDbCombo widget with a model. See gnome_db_combo_set_model() for
+ * more information about the @n_cols and @cols_index usage.
  *
  * Returns: the newly-created widget.
  */
@@ -250,26 +266,29 @@ static void cell_layout_data_func (GtkCellLayout *cell_layout, GtkCellRenderer *
  * @n_cols: number of columns in the model to be shown
  * @cols_index: index of each column to be shown
  *
- * Associate a #GdaDataModel with the given combo widget. Doing so makes the
+ * Makes @combo display data stored in @model (makes the
  * combo widget refresh its list of values and display the values contained
- * in the model, in the given position. A NULL @model will make the combo empty
+ * in the model). A NULL @model will make the combo empty
  * and disassociate the previous model, if any.
+ *
+ * if @n_cols is 0, then all the columns of @model will be displayed in @combo.
  */
 void
 gnome_db_combo_set_model (GnomeDbCombo *combo, GdaDataModel *model, gint n_cols, gint *cols_index)
 {
+	gint ln_cols;
+	gint *lcols_index;
+	
 	g_return_if_fail (GNOME_DB_IS_COMBO (combo));
 	g_return_if_fail (model == NULL || GDA_IS_DATA_MODEL (model));
 
 	/* reset all */
-	if (combo->priv->proxy) {
-		g_object_unref (G_OBJECT (combo->priv->proxy));
-		combo->priv->proxy = NULL;
-	}
-	if (combo->priv->model) {
-		g_object_unref (G_OBJECT (combo->priv->model));
-		combo->priv->model = NULL;
+	if (combo->priv->store) {
+		g_object_unref (G_OBJECT (combo->priv->store));
+		combo->priv->store = NULL;
 	}
+	if (combo->priv->model) 
+		model_destroyed_cb (combo->priv->model, combo);
 	if (combo->priv->cols_index) {
 		g_free (combo->priv->cols_index);
 		combo->priv->cols_index = NULL;
@@ -279,40 +298,52 @@ gnome_db_combo_set_model (GnomeDbCombo *combo, GdaDataModel *model, gint n_cols,
 
 	/* set model */
 	if (model) {
-		GnomeDbDataModel *tmp;
-
-		if (IS_GNOME_DB_DATA_MODEL (model)) {
-			tmp = GNOME_DB_DATA_MODEL (model);
-			g_object_ref (G_OBJECT (model));
-		}
-		else 
-			tmp = GNOME_DB_DATA_MODEL (gnome_db_model_wrapper_new (NULL, model));
-
-		combo->priv->model = tmp;
+		combo->priv->model = model;
+		g_object_ref (model);
+		gda_object_connect_destroy (model, G_CALLBACK (model_destroyed_cb), combo);
 		
-		combo->priv->proxy = GNOME_DB_DATA_PROXY (gnome_db_data_proxy_new (combo->priv->model));
-		gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (combo->priv->proxy));
+		combo->priv->store = GNOME_DB_DATA_STORE (gnome_db_data_store_new (combo->priv->model));
+		gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (combo->priv->store));
+		g_signal_connect (G_OBJECT (model), "changed",
+				  G_CALLBACK (model_changed_cb), combo);
 	} 
+	
+	if (!n_cols && model) {
+		gint i;
+		ln_cols = gda_data_model_get_n_columns (model);
+		lcols_index = g_new (gint, ln_cols);
+		for (i = 0; i < ln_cols; i++)
+			lcols_index [i] = i;	
+	}
+	else {
+		ln_cols = n_cols;
+		lcols_index = cols_index;
+	}
 
-	/* set columns */
-	if (n_cols && model) {
+	/* set columns with cell renderers*/
+	if (ln_cols && model) {
 		gint i, index;
 		GtkCellRenderer *renderer;
-		GnomeDbDataHandler *dh;
-		GnomeDbField *field;
+		GdaDataHandler *dh;
+		GdaDict *dict;
 
 		/* local copy */
-		combo->priv->cols_index = g_new0 (gint, n_cols);
-		combo->priv->n_cols = n_cols;
-		memcpy (combo->priv->cols_index, cols_index, sizeof (gint) * n_cols);
+		combo->priv->cols_index = g_new0 (gint, ln_cols);
+		combo->priv->n_cols = ln_cols;
+		memcpy (combo->priv->cols_index, lcols_index, sizeof (gint) * ln_cols);
 
 		/* create cell renderers */
-		for (i=0; i<n_cols; i++) {
+		dict = gda_object_get_dict (GDA_OBJECT (model));
+		for (i=0; i<ln_cols; i++) {
+			GdaColumn *column;
+			GType type;
+
 			index = combo->priv->cols_index [i];
 
-			field = gnome_db_entity_get_field_by_index (GNOME_DB_ENTITY (combo->priv->model), index);
-			dh = gnome_db_server_data_type_get_handler (gnome_db_field_get_data_type (field));
-				
+			column = gda_data_model_describe_column (model, index);
+			type = gda_column_get_g_type (column);
+			dh = gda_dict_get_default_handler (dict, type);
+			
 			renderer = gtk_cell_renderer_text_new ();
 			g_object_set_data (G_OBJECT (renderer), "data_handler", dh);
 			g_object_set_data (G_OBJECT (renderer), "colnum", GINT_TO_POINTER (index));
@@ -322,22 +353,25 @@ gnome_db_combo_set_model (GnomeDbCombo *combo, GdaDataModel *model, gint n_cols,
 			/* Don't unref the renderer! */
 		}
 	}
+	
+	if (!n_cols && model)
+		g_free (lcols_index);
 }
 
 static void
 cell_layout_data_func (GtkCellLayout *cell_layout, GtkCellRenderer *cell,
 		       GtkTreeModel *tree_model, GtkTreeIter *iter, GnomeDbCombo *combo)
 {
-	GnomeDbDataHandler *dh;
+	GdaDataHandler *dh;
 	gint colnum;
-	const GdaValue *value;
+	const GValue *value;
 	gchar *str;
 	
 	dh = g_object_get_data (G_OBJECT (cell), "data_handler");
 	colnum = GPOINTER_TO_INT (g_object_get_data  (G_OBJECT (cell), "colnum"));
-	
+
 	gtk_tree_model_get (tree_model, iter, colnum, &value, -1);
-	str = gnome_db_data_handler_get_str_from_value (dh, value);
+	str = gda_data_handler_get_str_from_value (dh, value);
 	g_object_set (G_OBJECT (cell), "text", str, NULL);
 	g_free (str);
 }
@@ -346,7 +380,7 @@ cell_layout_data_func (GtkCellLayout *cell_layout, GtkCellRenderer *cell,
  * gnome_db_combo_get_model
  * @combo: a #GnomeDbCombo widget.
  *
- * This function returns the #GdaDataModel stored in the #GnomeDbCombo.
+ * This function returns the #GdaDataModel from which @combo displays values.
  *
  * Returns: a #GdaDataModel containing the data from the #GnomeDbCombo widget.
  */
@@ -364,9 +398,12 @@ gnome_db_combo_get_model (GnomeDbCombo *combo)
 /**
  * gnome_db_combo_set_values
  * @combo: a #GnomeDbCombo widget
- * @values: a list of #GdaValue objects
+ * @values: a list of #GValue
  *
- * Sets the currently selected row of @combo from the values stored in @values.
+ * Sets the currently selected row of @combo from the values stored in @values. 
+ *
+ * WARNING: @values must contain one value for each column set to be displayed when the
+ * data model was associated to @combo.
  *
  * Returns: TRUE if a row in the model was found to match the list of values.
  */
@@ -376,7 +413,7 @@ gnome_db_combo_set_values (GnomeDbCombo *combo, const GSList *values)
 	g_return_val_if_fail (GNOME_DB_IS_COMBO (combo), FALSE);
 	g_return_val_if_fail (combo->priv, FALSE);
 	g_return_val_if_fail (combo->priv->cols_index, FALSE);
-	g_return_val_if_fail (g_slist_length (values) == combo->priv->n_cols, FALSE);
+	g_return_val_if_fail (g_slist_length ((GSList *) values) == combo->priv->n_cols, FALSE);
 
 	return gnome_db_combo_set_values_ext (combo, values, combo->priv->cols_index);
 }
@@ -388,14 +425,18 @@ gnome_db_combo_set_values (GnomeDbCombo *combo, const GSList *values)
  * Get a list of the currently selected values in @combo. The list itself must be free'd using g_slist_free(), 
  * but not the values it contains.
  *
- * Returns: a new list of values
+ * WARNING: @values will contain one value for each column set to be displayed when the
+ * data model was associated to @combo.
+ *
+ * Returns: a new list of values, or %NULL if there is no displayed data in @combo.
  */
 GSList *
 gnome_db_combo_get_values (GnomeDbCombo *combo)
 {
 	g_return_val_if_fail (GNOME_DB_IS_COMBO (combo), NULL);
 	g_return_val_if_fail (combo->priv, NULL);
-	g_return_val_if_fail (combo->priv->proxy, NULL);
+	if (!combo->priv->store)
+		return NULL;
 	g_return_val_if_fail (combo->priv->n_cols, NULL);
 	g_return_val_if_fail (combo->priv->cols_index, NULL);
 	
@@ -405,36 +446,36 @@ gnome_db_combo_get_values (GnomeDbCombo *combo)
 /**
  * gnome_db_combo_set_values_ext
  * @combo: a #GnomeDbCombo widget
- * @values: a list of #GdaValue objects
+ * @values: a list of #GValue objects
  * @cols_index: array of gint, index of column to which each value in @values corresponds, or %NULL
  *
  * Sets the currently selected row of @combo from the values stored in @values, assuming that
- * the values correspond to the columns listed in @cols_index. @cols_index must contain at least as
+ * these values correspond to the columns listed in @cols_index. @cols_index must contain at least as
  * many #gint as there are elements in @values;
  *
- * if @cols_index is %NULL, then it is assumed that @values has the same number of columns than @combo's data
- * model and that the values in @values are ordered in the same way as the columns of @combo's data model.
+ * if @cols_index is %NULL, then it is assumed that @values has the same number of columns 
+ * than @combo's data
+ * model and that the values in @values are ordered in the same way as the columns of 
+ * @combo's data model.
  *
  * Returns: TRUE if a row in the model was found to match the list of values.
  */
 gboolean
 gnome_db_combo_set_values_ext (GnomeDbCombo *combo, const GSList *values, gint *cols_index)
 {
-	GtkTreeIter iter;
+	gint row;
+	GdaDataProxy *proxy;
 
 	g_return_val_if_fail (GNOME_DB_IS_COMBO (combo), FALSE);
 	g_return_val_if_fail (combo->priv, FALSE);
-	g_return_val_if_fail (combo->priv->proxy, FALSE);
+	g_return_val_if_fail (combo->priv->store, FALSE);
 	g_return_val_if_fail (values, FALSE);
-	
-	if (gnome_db_data_proxy_get_iter_from_values (combo->priv->proxy, &iter, values, cols_index)) {
-		gtk_combo_box_set_active_iter (GTK_COMBO_BOX (combo), &iter);
-		return TRUE;
-	}
-	else {
-		gtk_combo_box_set_active (GTK_COMBO_BOX (combo), -1);
-		return FALSE;
-	}
+
+	proxy = gnome_db_data_store_get_proxy (combo->priv->store);
+	row = gda_data_proxy_find_row_from_values (proxy, (GSList *) values, cols_index);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (combo), row);
+
+	return (row >= 0) ? TRUE : FALSE;
 }
 
 /**
@@ -446,9 +487,9 @@ gnome_db_combo_set_values_ext (GnomeDbCombo *combo, const GSList *values, gint *
  * Get a list of the currently selected values in @combo. The list itself must be free'd using g_slist_free(), 
  * but not the values it contains. If there is no selected value in @combo, then %NULL is returned.
  *
- * if n_cols equals 0 and @cols_index is %NULL, then a #GdaValue will be returned for each column of @combo's data model.
+ * if n_cols equals 0 and @cols_index is %NULL, then a #GValue will be returned for each column of @combo's data model.
  *
- * Returns: a new list of values, or %NULL
+ * Returns: a new list of values, or %NULL if there is no displayed data in @combo.
  */
 GSList *
 gnome_db_combo_get_values_ext (GnomeDbCombo *combo, gint n_cols, gint *cols_index)
@@ -456,14 +497,18 @@ gnome_db_combo_get_values_ext (GnomeDbCombo *combo, gint n_cols, gint *cols_inde
 	GtkTreeIter iter;
 	GSList *retval = NULL;
 	gint index, nbcols;
-	GdaValue *value;
+	GValue *value;
 
 	g_return_val_if_fail (GNOME_DB_IS_COMBO (combo), NULL);
 	g_return_val_if_fail (combo->priv, NULL);
-	g_return_val_if_fail (combo->priv->proxy, NULL);
+	if (! combo->priv->store)
+		return NULL;
 	if (!n_cols) {
+		GdaDataProxy *proxy;
+
 		g_return_val_if_fail (!cols_index, NULL);
-		nbcols = gnome_db_data_proxy_get_n_columns (combo->priv->proxy);
+		proxy = gnome_db_data_store_get_proxy (combo->priv->store);
+		nbcols = gda_data_model_get_n_columns ((GdaDataModel *) proxy);
 	}
 	else {
 		g_return_val_if_fail (n_cols > 0, NULL);
@@ -472,7 +517,7 @@ gnome_db_combo_get_values_ext (GnomeDbCombo *combo, gint n_cols, gint *cols_inde
 
 	if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (combo), &iter)) {
 		for (index = 0;	index < nbcols; index++) {
-			gtk_tree_model_get (GTK_TREE_MODEL (combo->priv->proxy), &iter, 
+			gtk_tree_model_get (GTK_TREE_MODEL (combo->priv->store), &iter, 
 					    cols_index ? cols_index[index] : index, &value, -1);
 			retval = g_slist_append (retval, value);
 		}
@@ -495,7 +540,7 @@ gnome_db_combo_add_undef_choice (GnomeDbCombo *combo, gboolean add_undef_choice)
 	g_return_if_fail (GNOME_DB_IS_COMBO (combo));
 	g_return_if_fail (combo->priv);
 
-	g_object_set (G_OBJECT (combo->priv->proxy), "prepend_null_entry", add_undef_choice, NULL);
+	g_object_set (G_OBJECT (combo->priv->store), "prepend_null_entry", add_undef_choice, NULL);
 }
 
 /**
@@ -519,7 +564,7 @@ gnome_db_combo_undef_selected (GnomeDbCombo *combo)
 	if (active_row == -1)
 		return TRUE;
 	
-	g_object_get (G_OBJECT (combo->priv->proxy), "prepend_null_entry", &has_undef_choice, NULL);
+	g_object_get (G_OBJECT (combo->priv->store), "prepend_null_entry", &has_undef_choice, NULL);
 	if (has_undef_choice && (active_row == 0))
 		return TRUE;
 
