@@ -159,7 +159,7 @@ data_widget_destroyed_cb (GnomeDbDataWidget *wid, GnomeDbDataWidgetInfo *info)
 					      G_CALLBACK (data_widget_destroyed_cb), info);
 	g_signal_handlers_disconnect_by_func (G_OBJECT (wid),
 					      G_CALLBACK (data_widget_proxy_changed_cb), info);
-	if (IS_GNOME_DB_RAW_GRID (info->priv->data_widget))
+	if (GNOME_DB_IS_RAW_GRID (info->priv->data_widget))
 		g_signal_handlers_disconnect_by_func (info->priv->data_widget,
 						      G_CALLBACK (raw_grid_selection_changed_cb), info);
 
@@ -206,7 +206,7 @@ gnome_db_data_widget_info_dispose (GObject *object)
 	GnomeDbDataWidgetInfo *info;
 
 	g_return_if_fail (object != NULL);
-	g_return_if_fail (IS_GNOME_DB_DATA_WIDGET_INFO (object));
+	g_return_if_fail (GNOME_DB_IS_DATA_WIDGET_INFO (object));
 	info = GNOME_DB_DATA_WIDGET_INFO (object);
 
 	if (info->priv) {
@@ -255,7 +255,7 @@ gnome_db_data_widget_info_set_property (GObject *object,
 						  G_CALLBACK (data_widget_destroyed_cb), info);
 				g_signal_connect (info->priv->data_widget, "proxy_changed",
 						  G_CALLBACK (data_widget_proxy_changed_cb), info);
-				if (IS_GNOME_DB_RAW_GRID (info->priv->data_widget))
+				if (GNOME_DB_IS_RAW_GRID (info->priv->data_widget))
 					g_signal_connect (info->priv->data_widget, "selection_changed",
 							  G_CALLBACK (raw_grid_selection_changed_cb), info);
 
@@ -581,7 +581,7 @@ modif_buttons_update (GnomeDbDataWidgetInfo *info)
 				is_inserted = gda_data_proxy_row_is_inserted (info->priv->proxy, row);
 			}
 			else 
-				if (IS_GNOME_DB_RAW_GRID (info->priv->data_widget)) {
+				if (GNOME_DB_IS_RAW_GRID (info->priv->data_widget)) {
 					/* bad for encapsulation, but very usefull... */
 					GList *sel, *list;
 					
@@ -611,11 +611,22 @@ modif_buttons_update (GnomeDbDataWidgetInfo *info)
 		}
 
 		if (info->priv->flags & GNOME_DB_DATA_WIDGET_INFO_ROW_MODIF_BUTTONS) {
+			GnomeDbDataWidgetWriteMode mode;
+			mode = gnome_db_data_widget_get_write_mode (info->priv->data_widget);
+
 			action = gtk_ui_manager_get_action (info->priv->uimanager, "/ToolBar/ActionCommit");
 			g_object_set (G_OBJECT (action), "sensitive", changed ? TRUE : FALSE, NULL);
+			if (mode == GNOME_DB_DATA_WIDGET_WRITE_ON_VALUE_CHANGE)
+				gtk_action_set_visible (action, FALSE);
+			else
+				gtk_action_set_visible (action, TRUE);
 			
 			action = gtk_ui_manager_get_action (info->priv->uimanager, "/ToolBar/ActionReset");
 			g_object_set (G_OBJECT (action), "sensitive", changed ? TRUE : FALSE, NULL);
+			if (mode == GNOME_DB_DATA_WIDGET_WRITE_ON_VALUE_CHANGE)
+				gtk_action_set_visible (action, FALSE);
+			else
+				gtk_action_set_visible (action, TRUE);
 			
 			action = gtk_ui_manager_get_action (info->priv->uimanager, "/ToolBar/ActionNew");
 			g_object_set (G_OBJECT (action), "sensitive", 
@@ -631,6 +642,13 @@ modif_buttons_update (GnomeDbDataWidgetInfo *info)
 			wrows = (flags & GDA_DATA_MODEL_ACCESS_DELETE) && 
 				(force_undel_btn || (to_be_deleted && has_selection));
 			g_object_set (G_OBJECT (action), "sensitive", wrows, NULL);
+
+			if ((mode == GNOME_DB_DATA_WIDGET_WRITE_ON_ROW_CHANGE) ||
+			    (mode == GNOME_DB_DATA_WIDGET_WRITE_ON_VALUE_CHANGE) ||
+			    (mode == GNOME_DB_DATA_WIDGET_WRITE_ON_VALUE_ACTIVATED))
+				gtk_action_set_visible (action, FALSE);
+			else 
+				gtk_action_set_visible (action, TRUE);
 		}
 	}
 
@@ -663,20 +681,6 @@ modif_buttons_update (GnomeDbDataWidgetInfo *info)
 		g_object_set (G_OBJECT (action), "sensitive", wrows && (sample_last_row < proxied_rows - 1), NULL);
 	}
 	
-	if (info->priv->proxy && (info->priv->flags & GNOME_DB_DATA_WIDGET_INFO_ROW_MODIF_BUTTONS)) {
-		gboolean autocommit;
-
-		g_object_get (G_OBJECT (info->priv->proxy), "autocommit", &autocommit, NULL);
-		action = gtk_ui_manager_get_action (info->priv->uimanager, "/ToolBar/ActionUndelete");
-		gtk_action_set_visible (action, !autocommit);
-
-		action = gtk_ui_manager_get_action (info->priv->uimanager, "/ToolBar/ActionCommit");
-		gtk_action_set_visible (action, !autocommit);
-
-		action = gtk_ui_manager_get_action (info->priv->uimanager, "/ToolBar/ActionReset");
-		gtk_action_set_visible (action, !autocommit);
-	}
-
 	if (info->priv->uimanager)
 		gtk_ui_manager_ensure_update (info->priv->uimanager); 
 }
