@@ -1,8 +1,9 @@
 /* GNOME DB library
- * Copyright (C) 1999-2002 The GNOME Foundation.
+ * Copyright (C) 1999 - 2005 The GNOME Foundation.
  *
  * AUTHORS:
  *      Rodrigo Moya <rodrigo@gnome-db.org>
+ *      Vivien Malerba <malerba@gnome-db.org>
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -25,12 +26,21 @@
 #ifdef HAVE_GTKSOURCEVIEW
 #include <gtksourceview/gtksourceview.h>
 #include <gtksourceview/gtksourcelanguagesmanager.h>
+#include <gtksourceview/gtksourcetag.h>
 #endif
 #include <libgda/gda-util.h>
-#include <libgnomedb/gnome-db-config.h>
+#include <libgda/gda-config.h>
 #include <libgnomedb/gnome-db-editor.h>
 #include <libgnomedb/gnome-db-util.h>
 
+#ifdef HAVE_GCONF
+#include <gconf/gconf-client.h>
+#define GNOME_DB_CONFIG_KEY_BROWSER_PANED_POSITION   "/apps/gnome-db/Browser/PanedPosition"
+#define GNOME_DB_CONFIG_KEY_EDITOR_HIGHLIGHT         "/apps/gnome-db/Editor/Highlight"
+#define GNOME_DB_CONFIG_KEY_EDITOR_SHOW_LINE_NUMBERS "/apps/gnome-db/Editor/ShowLineNumbers"
+#define GNOME_DB_CONFIG_KEY_EDITOR_TAB_STOP          "/apps/gnome-db/Editor/TabStop"
+#endif
+
 #define PARENT_TYPE GTK_TYPE_VBOX
 
 typedef void (* CreateTagsFunc) (GnomeDbEditor *editor, const gchar *language);
@@ -76,7 +86,7 @@ create_tags_for_sql (GnomeDbEditor *editor, const gchar *language)
 		GList *tag_list = NULL;
 
 		/* add SQL keywords */
-		tag = gtk_pattern_tag_new ("keywords",
+		tag = gtk_pattern_tag_new ("keywords", "keywords",
 					   "\\b\\(add\\|alter\\|and\\|as\\|begin\\|by\\|commit\\|create\\|delete"
 					   "\\|drop\\|exists\\|from\\|group\\|having\\|in\\|insert\\|into"
 					   "\\|is\\|key\\|not\\|null\\|or\\|order\\|primary\\|references"
@@ -86,30 +96,30 @@ create_tags_for_sql (GnomeDbEditor *editor, const gchar *language)
 		tag_list = g_list_append (tag_list, tag);
 		
 		/* add aggregates */
-		tag = gtk_pattern_tag_new ("functions",
+		tag = gtk_pattern_tag_new ("functions", "functions",
 					   "\\b\\(avg\\|count\\|max\\|min\\|sum\\)\\b");
 		g_object_set (G_OBJECT (tag), "foreground", "navy", NULL);
 		tag_list = g_list_append (tag_list, tag);
 		
 		/* add strings and numbers */
-		tag = gtk_syntax_tag_new ("string", "\"", "\"");
+		tag = gtk_syntax_tag_new ("string", "string", "\"", "\"");
 		g_object_set (G_OBJECT (tag), "foreground", "forest green", NULL);
 		tag_list = g_list_append (tag_list, tag);
 		
-		tag = gtk_syntax_tag_new ("single_quoted_string", "'", "'");
+		tag = gtk_syntax_tag_new ("single_quoted_string", "single_quoted_string", "'", "'");
 		g_object_set (G_OBJECT (tag), "foreground", "forest green", NULL);
 		tag_list = g_list_append (tag_list, tag);
 		
-		tag = gtk_pattern_tag_new ("numbers", "\\b[0-9]+\\.?\\b");
+		tag = gtk_pattern_tag_new ("numbers", "numbers", "\\b[0-9]+\\.?\\b");
 		g_object_set (G_OBJECT (tag), "weight", PANGO_WEIGHT_BOLD, NULL);
 		tag_list = g_list_append (tag_list, tag);
 		
 		/* add comments */
-		tag = gtk_syntax_tag_new ("comment", "--", "\n");
+		tag = gtk_syntax_tag_new ("comment", "comment", "--", "\n");
 		g_object_set (G_OBJECT (tag), "foreground", "gray", "style", PANGO_STYLE_ITALIC, NULL);
 		tag_list = g_list_append (tag_list, tag);
 		
-		tag = gtk_syntax_tag_new ("comment_multiline", "/\\*", "\\*/");
+		tag = gtk_syntax_tag_new ("comment_multiline", "comment_multiline", "/\\*", "\\*/");
 		g_object_set (G_OBJECT (tag), "foreground", "gray", "style", PANGO_STYLE_ITALIC, NULL);
 		tag_list = g_list_append (tag_list, tag);
 		
@@ -136,6 +146,7 @@ gnome_db_editor_class_init (GnomeDbEditorClass *klass)
 	object_class->finalize = gnome_db_editor_finalize;
 }
 
+#ifdef HAVE_GCONF
 static void
 configuration_changed_cb (GConfClient *conf_client, guint cnxn_id, GConfEntry *entry, gpointer user_data)
 {
@@ -147,38 +158,50 @@ configuration_changed_cb (GConfClient *conf_client, guint cnxn_id, GConfEntry *e
 #ifdef HAVE_GTKSOURCEVIEW
 		gtk_source_view_set_show_line_numbers (
 			GTK_SOURCE_VIEW (editor->priv->text),
-			gnome_db_config_get_boolean (GNOME_DB_CONFIG_KEY_EDITOR_SHOW_LINE_NUMBERS));
+			gconf_client_get_bool (gconf_client_get_default (), GNOME_DB_CONFIG_KEY_EDITOR_SHOW_LINE_NUMBERS, NULL));
 #else
 #endif
 	} else if (!strcmp (entry->key, GNOME_DB_CONFIG_KEY_EDITOR_TAB_STOP)) {
 #ifdef HAVE_GTKSOURCEVIEW
-		int tab = gnome_db_config_get_int (GNOME_DB_CONFIG_KEY_EDITOR_TAB_STOP);
-		gtk_source_view_set_tabs_width (
-			GTK_SOURCE_VIEW (editor->priv->text),
-			tab ? tab : 8);
+		int tab = gconf_client_get_int (gconf_client_get_default (), GNOME_DB_CONFIG_KEY_EDITOR_TAB_STOP, NULL);
+		gtk_source_view_set_tabs_width (GTK_SOURCE_VIEW (editor->priv->text),
+						tab ? tab : 8);
 #else
 #endif
 	} else if (!strcmp (entry->key, GNOME_DB_CONFIG_KEY_EDITOR_HIGHLIGHT)) {
 		gnome_db_editor_set_highlight (editor,
-					       gnome_db_config_get_boolean (GNOME_DB_CONFIG_KEY_EDITOR_HIGHLIGHT));
+					       gconf_client_get_bool (gconf_client_get_default (), 
+								      GNOME_DB_CONFIG_KEY_EDITOR_HIGHLIGHT, NULL));
 	}
 }
+#endif
 
 static void
 gnome_db_editor_init (GnomeDbEditor *editor, GnomeDbEditorClass *klass)
 {
-	int tab;
+	int tab = 8;
+	gboolean highlight = TRUE;
+	gboolean showlinesno = FALSE;
 
 	g_return_if_fail (GNOME_DB_IS_EDITOR (editor));
 
 	/* allocate private structure */
 	editor->priv = g_new0 (GnomeDbEditorPrivate, 1);
 
-	editor->priv->config_lid = gnome_db_config_add_listener (
-		"/apps/gnome-db/Editor",
-		(GConfClientNotifyFunc) configuration_changed_cb,
-		editor);
-
+#ifdef HAVE_GCONF
+	gconf_client_add_dir (gconf_client_get_default (), "/apps/gnome-db/Editor", 
+			      GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
+	
+	editor->priv->config_lid = gconf_client_notify_add (gconf_client_get_default (), 
+							    "/apps/gnome-db/Editor",
+							    (GConfClientNotifyFunc) configuration_changed_cb,
+							    editor, NULL, NULL);
+	highlight = gconf_client_get_bool (gconf_client_get_default (),
+					   GNOME_DB_CONFIG_KEY_EDITOR_HIGHLIGHT, NULL);
+	showlinesno = gconf_client_get_bool (gconf_client_get_default (),
+					     GNOME_DB_CONFIG_KEY_EDITOR_SHOW_LINE_NUMBERS, NULL);
+	tab = gconf_client_get_int (gconf_client_get_default (), GNOME_DB_CONFIG_KEY_EDITOR_TAB_STOP, NULL);
+#endif
 	/* set up widgets */
 	editor->priv->scrolled_window = gnome_db_new_scrolled_window_widget ();
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (editor->priv->scrolled_window),
@@ -187,15 +210,10 @@ gnome_db_editor_init (GnomeDbEditor *editor, GnomeDbEditorClass *klass)
 
 #ifdef HAVE_GTKSOURCEVIEW
 	editor->priv->text = gtk_source_view_new ();
-	gtk_source_buffer_set_highlight (gtk_text_view_get_buffer (GTK_TEXT_VIEW (editor->priv->text)),
-					 gnome_db_config_get_boolean (GNOME_DB_CONFIG_KEY_EDITOR_HIGHLIGHT));
-	gtk_source_view_set_show_line_numbers (
-		GTK_SOURCE_VIEW (editor->priv->text),
-		gnome_db_config_get_boolean (GNOME_DB_CONFIG_KEY_EDITOR_SHOW_LINE_NUMBERS));
-	tab = gnome_db_config_get_int (GNOME_DB_CONFIG_KEY_EDITOR_TAB_STOP);
-	gtk_source_view_set_tabs_width (
-		GTK_SOURCE_VIEW (editor->priv->text),
-		tab ? tab : 8);
+	gtk_source_buffer_set_highlight (GTK_SOURCE_BUFFER (gtk_text_view_get_buffer (GTK_TEXT_VIEW (editor->priv->text))),
+					 highlight);
+	gtk_source_view_set_show_line_numbers (GTK_SOURCE_VIEW (editor->priv->text), showlinesno);
+	gtk_source_view_set_tabs_width (GTK_SOURCE_VIEW (editor->priv->text), tab);
 	gtk_widget_show (editor->priv->text);
 #else
 	editor->priv->text = gnome_db_new_text_widget (NULL);
@@ -221,6 +239,9 @@ gnome_db_editor_finalize (GObject *object)
 	g_return_if_fail (GNOME_DB_IS_EDITOR (editor));
 
 	/* free memory */
+#ifdef HAVE_GCONF
+	gconf_client_notify_remove (gconf_client_get_default (), editor->priv->config_lid);
+#endif
 	g_free (editor->priv);
 	editor->priv = NULL;
 
@@ -290,7 +311,7 @@ gboolean
 gnome_db_editor_get_editable (GnomeDbEditor *editor)
 {
         g_return_val_if_fail (GNOME_DB_IS_EDITOR (editor), FALSE);
-                                                                                                                                                                       
+
         return gtk_text_view_get_editable (GTK_TEXT_VIEW (editor->priv->text));
 }
 
@@ -392,7 +413,6 @@ gnome_db_editor_load_from_file (GnomeDbEditor *editor, const gchar *filename)
 {
 	gboolean retval = TRUE;
 	gchar *contents;
-	GError *err = NULL;
 
 	g_return_val_if_fail (GNOME_DB_IS_EDITOR (editor), FALSE);
 	g_return_val_if_fail (filename != NULL, FALSE);
@@ -401,9 +421,8 @@ gnome_db_editor_load_from_file (GnomeDbEditor *editor, const gchar *filename)
 	if (contents) {
 		gnome_db_text_set_text (GTK_TEXT_VIEW (editor->priv->text), contents, strlen (contents));
 		g_free (contents);
-	} else {
+	} else 
 		retval = FALSE;
-	}
 
 	return retval;
 }
