@@ -25,6 +25,7 @@
 #include <gtk/gtknotebook.h>
 #include <gtk/gtkstock.h>
 #include <gtk/gtktable.h>
+#include <gtk/gtkhbox.h>
 #include <gtk/gtkwindow.h>
 #include <libgnomedb/gnome-db-login.h>
 #include <libgnomedb/gnome-db-login-dialog.h>
@@ -115,10 +116,10 @@ gnome_db_login_dialog_init (GnomeDbLoginDialog *dialog, GnomeDbLoginDialogClass
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox, TRUE, TRUE, 0);
 
-	image = gtk_image_new_from_file (LIBGNOMEDB_ICONSDIR "/gnome-db-database-login_48x48.png");
+	image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_AUTHENTICATION, GTK_ICON_SIZE_DIALOG);
         gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
 	gtk_widget_show (image);
-	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 5);
 
 	nb = gtk_notebook_new ();
 	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (nb), FALSE);
@@ -132,7 +133,7 @@ gnome_db_login_dialog_init (GnomeDbLoginDialog *dialog, GnomeDbLoginDialogClass
 	gtk_notebook_append_page (GTK_NOTEBOOK (nb), vbox, NULL);
 	gtk_widget_show (vbox);
 	
-	str = g_strdup_printf ("<b>%s:</b>\n%s", _("Data source selection"),
+	str = g_strdup_printf ("<b>%s:</b>\n%s", _("Connection opening"),
 			       _("Enter the arguments below to open a connection\n"
 				 "to a data source"));
 	label = gtk_label_new ("");
@@ -250,8 +251,7 @@ gnome_db_login_dialog_new (const gchar *title)
 	GdkPixbuf *icon;
 	GnomeDbLoginDialog *dialog;
 
-	dialog = g_object_new (GNOME_DB_TYPE_LOGIN_DIALOG, NULL);
-	gtk_window_set_title (GTK_WINDOW (dialog), title);
+	dialog = g_object_new (GNOME_DB_TYPE_LOGIN_DIALOG, "title", title, NULL);
 
 	icon = gdk_pixbuf_new_from_file (LIBGNOMEDB_ICONSDIR "/gnome-db.png", NULL);
 	if (icon) {
@@ -266,9 +266,10 @@ gnome_db_login_dialog_new (const gchar *title)
  * gnome_db_login_dialog_run
  * @dialog:
  *
+ * Shows the login dialog and waits for the user to enter its username and
+ * password and perform an action on the dialog.
  *
- *
- * Returns:
+ * Returns: TRUE if the user wants to connect
  */
 gboolean
 gnome_db_login_dialog_run (GnomeDbLoginDialog *dialog)
@@ -337,3 +338,4 @@ gnome_db_login_dialog_get_login_widget (GnomeDbLoginDialog *dialog)
 	g_return_val_if_fail (GNOME_DB_IS_LOGIN_DIALOG (dialog), NULL);
 	return dialog->priv->login;
 }
+
