@@ -508,7 +508,7 @@ gnome_db_raw_form_initialize (GnomeDbRawForm *form, GtkWidget *layout, GHashTabl
 	 * the form itself 
 	 */
 	if (!layout && gda_data_proxy_is_read_only (form->priv->proxy))
-		gnome_db_basic_form_show_entries_actions (GNOME_DB_BASIC_FORM (form), FALSE);
+		gnome_db_basic_form_show_entry_actions (GNOME_DB_BASIC_FORM (form), FALSE);
 
 	list = GDA_PARAMETER_LIST (form->priv->iter)->parameters;
 	while (list) {
@@ -763,7 +763,7 @@ gnome_db_raw_form_show_column_actions (GnomeDbDataWidget *iface, gint column, gb
 	g_return_if_fail (form->priv);
 	
 	/* REM: don't take care of the @column argument */
-	gnome_db_basic_form_show_entries_actions (GNOME_DB_BASIC_FORM (form), show_actions);
+	gnome_db_basic_form_show_entry_actions (GNOME_DB_BASIC_FORM (form), show_actions);
 }
 
 static GtkActionGroup *
