@@ -49,6 +49,7 @@ static void init_tree_view (GnomeDbRawGrid *grid);
 static void proxy_destroyed_cb (GdaDataProxy *proxy, GnomeDbRawGrid *grid);
 static void proxy_sample_changed_cb (GdaDataProxy *proxy, gint sample_start, gint sample_end, GnomeDbRawGrid *grid);
 static void paramlist_public_data_changed_cb (GdaParameterList *paramlist, GnomeDbRawGrid *grid);
+static void paramlist_param_plugin_changed_cb (GdaParameterList *paramlist, GdaParameter *param, GnomeDbRawGrid *grid);
 static void iter_row_changed_cb (GdaDataModelIter *iter, gint row, GnomeDbRawGrid *grid);
 
 /* GnomeDbDataWidget interface */
@@ -141,8 +142,8 @@ static void action_next_chunck_cb (GtkAction *action, GnomeDbRawGrid *grid);
 static void action_last_chunck_cb (GtkAction *action, GnomeDbRawGrid *grid);
 
 static GtkActionEntry ui_actions[] = {
-	{ "ActionNew", GTK_STOCK_NEW, "_New", NULL, "Create a new data entry", G_CALLBACK (action_new_cb)},
-	{ "ActionDelete", GTK_STOCK_DELETE, "_Delete", NULL, "Delete the selected entry", G_CALLBACK (action_delete_cb)},
+	{ "ActionNew", GTK_STOCK_ADD, "_New", NULL, "Create a new data entry", G_CALLBACK (action_new_cb)},
+	{ "ActionDelete", GTK_STOCK_REMOVE, "_Delete", NULL, "Delete the selected entry", G_CALLBACK (action_delete_cb)},
 	{ "ActionUndelete", GTK_STOCK_UNDELETE, "_Undelete", NULL, "Cancels the deletion of the selected entry", 
 	  G_CALLBACK (action_undelete_cb)},
 	{ "ActionCommit", GTK_STOCK_SAVE, "_Commit", NULL, "Commit the latest changes", G_CALLBACK (action_commit_cb)},
@@ -262,7 +263,7 @@ gnome_db_raw_grid_init (GnomeDbRawGrid *grid)
 	grid->priv = g_new0 (GnomeDbRawGridPriv, 1);
 	grid->priv->store = NULL;
 	grid->priv->proxy = NULL;
-	grid->priv->default_show_info_cell = TRUE;
+	grid->priv->default_show_info_cell = FALSE;
 	grid->priv->default_show_global_actions = TRUE;
 	grid->priv->columns_data = NULL;
 	grid->priv->export_type = 2;
@@ -315,7 +316,7 @@ gnome_db_raw_grid_dispose (GObject *object)
 	GnomeDbRawGrid *grid;
 
 	g_return_if_fail (object != NULL);
-	g_return_if_fail (IS_GNOME_DB_RAW_GRID (object));
+	g_return_if_fail (GNOME_DB_IS_RAW_GRID (object));
 	grid = GNOME_DB_RAW_GRID (object);
 
 	if (grid->priv) {
@@ -347,7 +348,7 @@ gnome_db_raw_grid_set_property (GObject *object,
         if (grid->priv) {
                 switch (param_id) {
 		case PROP_MODEL:
-			{														
+			{
 				GdaDataModel *model = GDA_DATA_MODEL(g_value_get_object (value));
 				if (model)
 					g_return_if_fail (GDA_IS_DATA_MODEL (model));
@@ -368,6 +369,9 @@ gnome_db_raw_grid_set_property (GObject *object,
 				grid->priv->iter = gda_data_model_create_iter (GDA_DATA_MODEL (grid->priv->proxy));
 				g_signal_connect (grid->priv->iter, "public_data_changed",
 						  G_CALLBACK (paramlist_public_data_changed_cb), grid);
+				g_signal_connect (grid->priv->iter, "param_plugin_changed",
+						  G_CALLBACK (paramlist_param_plugin_changed_cb), grid);
+
 				g_signal_connect (grid->priv->iter, "row_changed",
 						  G_CALLBACK (iter_row_changed_cb), grid);
 				gda_data_model_iter_invalidate_contents (grid->priv->iter);
@@ -387,15 +391,15 @@ gnome_db_raw_grid_set_property (GObject *object,
 	
 				while (list) {
 					COLUMN_DATA (list->data)->info_shown = show;
-					g_object_set (G_OBJECT (COLUMN_DATA (list->data)->info_cell), "visible", show, NULL);
+					g_object_set (G_OBJECT (COLUMN_DATA (list->data)->info_cell), "visible", 
+						      show, NULL);
 					list = g_slist_next (list);
 				}
 			}
 			break;
 			
 		case PROP_GLOBAL_ACTIONS_VISIBLE:
-			
-			gtk_action_group_set_visible(grid->priv->actions_group, g_value_get_boolean(value));
+			gtk_action_group_set_visible (grid->priv->actions_group, g_value_get_boolean (value));
 			break;
 		
 		default:
@@ -450,7 +454,7 @@ gnome_db_raw_grid_get_selection (GnomeDbRawGrid *grid)
 	GtkTreeSelection *selection;
 	GList *selected_rows;
 
-	g_return_val_if_fail (grid && IS_GNOME_DB_RAW_GRID (grid), NULL);
+	g_return_val_if_fail (grid && GNOME_DB_IS_RAW_GRID (grid), NULL);
 	g_return_val_if_fail (grid->priv, NULL);
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (grid));
@@ -508,7 +512,7 @@ static void     data_cell_value_changed (GtkCellRenderer *renderer, const gchar
 static void     data_cell_values_changed (GtkCellRenderer *renderer, const gchar *path, 
 					  GSList *new_values, GSList *all_new_values, GnomeDbRawGrid *grid);
 static void     data_cell_status_changed (GtkCellRenderer *renderer, const gchar *path, 
-					  GValueAttribute requested_action, GnomeDbRawGrid *grid);
+					  GdaValueAttribute requested_action, GnomeDbRawGrid *grid);
 
 /*
  * Creates the GtkTreeView's columns, from the grid->priv->store GtkTreeModel
@@ -719,25 +723,27 @@ cell_renderer_value_set_attributes (GtkTreeViewColumn *tree_column,
 			values = utility_proxy_compute_values_for_group (group, grid->priv->store, 
 									 grid->priv->iter, iter, FALSE);
 			g_object_set (G_OBJECT (cell), 
-				      "value_attributes", attributes,
 				      "values_display", values,
+				      "value_attributes", attributes,
 				      "editable", !column_data->data_locked && !(attributes & GDA_VALUE_ATTR_NO_MODIF),
 				      "cell_background", GNOME_DB_COLOR_NORMAL_MODIF,
 				      "cell_background-set", 
 				      ! (attributes & GDA_VALUE_ATTR_IS_UNCHANGED) || to_be_deleted,
 				      "to_be_deleted", to_be_deleted, 
+				      "visible", !(attributes & GDA_VALUE_ATTR_UNUSED),
 				      NULL);
 			g_list_free (values);
 		}
 		else {
 			g_object_set (G_OBJECT (cell), 
-				      "value_attributes", attributes,
 				      "values_display", values,
+				      "value_attributes", attributes,
 				      "editable", !column_data->data_locked && !(attributes & GDA_VALUE_ATTR_NO_MODIF),
 				      "cell_background", GNOME_DB_COLOR_NORMAL_MODIF,
 				      "cell_background-set", 
 				      ! (attributes & GDA_VALUE_ATTR_IS_UNCHANGED) || to_be_deleted,
 				      "to_be_deleted", to_be_deleted, 
+				      "visible", !(attributes & GDA_VALUE_ATTR_UNUSED),
 				      NULL);
 			g_list_free (values);
 		}
@@ -760,12 +766,13 @@ cell_renderer_value_set_attributes (GtkTreeViewColumn *tree_column,
 				    col, &value, 
 				    offset + col, &attributes, -1);
 		g_object_set (G_OBJECT (cell), 
-			      "value_attributes", attributes,
 			      "value", value,
+			      "value_attributes", attributes,
 			      "editable", !column_data->data_locked && !(attributes & GDA_VALUE_ATTR_NO_MODIF),
 			      "cell_background", GNOME_DB_COLOR_NORMAL_MODIF,
 			      "cell_background-set", ! (attributes & GDA_VALUE_ATTR_IS_UNCHANGED) || to_be_deleted,
 			      "to_be_deleted", to_be_deleted, 
+			      "visible", !(attributes & GDA_VALUE_ATTR_UNUSED),
 			      NULL);
 	}
 }
@@ -802,6 +809,7 @@ cell_renderer_info_set_attributes (GtkTreeViewColumn *tree_column,
 			      "cell_background", GNOME_DB_COLOR_NORMAL_MODIF,
 			      "cell_background-set", ! (attributes & GDA_VALUE_ATTR_IS_UNCHANGED) || to_be_deleted,
 			      "to_be_deleted", to_be_deleted, 
+			      "visible", column_data->info_shown && !(attributes & GDA_VALUE_ATTR_UNUSED),
 			      NULL);
 	}
 	else {
@@ -825,6 +833,7 @@ cell_renderer_info_set_attributes (GtkTreeViewColumn *tree_column,
 			      "cell_background", GNOME_DB_COLOR_NORMAL_MODIF,
 			      "cell_background-set", ! (attributes & GDA_VALUE_ATTR_IS_UNCHANGED) || to_be_deleted,
 			      "to_be_deleted", to_be_deleted, 
+			      "visible", column_data->info_shown && !(attributes & GDA_VALUE_ATTR_UNUSED),
 			      NULL);
 	}
 }
@@ -852,7 +861,7 @@ data_cell_value_changed (GtkCellRenderer *renderer, const gchar *path, const GVa
 		    gnome_db_data_store_set_value (grid->priv->store, &iter, col, new_value);
 	}
 
-#ifdef debug_NO
+#ifdef debug_no
 	DEBUG_HEADER;
 	gda_object_dump (grid->priv->proxy, 5);
 #endif
@@ -945,7 +954,7 @@ set_iter_from_path (GnomeDbRawGrid *grid, const gchar *path, GtkTreeIter *iter)
  * Actions
  */
 static void
-data_cell_status_changed (GtkCellRenderer *renderer, const gchar *path, GValueAttribute requested_action,
+data_cell_status_changed (GtkCellRenderer *renderer, const gchar *path, GdaValueAttribute requested_action,
 			  GnomeDbRawGrid *grid)
 {
 	GtkTreePath *treepath;
@@ -1019,7 +1028,7 @@ data_cell_status_changed (GtkCellRenderer *renderer, const gchar *path, GValueAt
 	}
 	gda_value_free (attribute);
 
-#ifdef debug_NO
+#ifdef debug_no
 	DEBUG_HEADER;
 	gda_object_dump (grid->priv->proxy, 0);
 #endif
@@ -1325,7 +1334,7 @@ menu_save_as_cb (GtkWidget *widget, GnomeDbRawGrid *grid)
 
 	str = g_strdup_printf ("<big><b>%s:</b></big>\n%s", _("Saving data to a file"), 
 			       _("The data will be exported without any of the modifications which may "
-				 "have been made and have not been comitted."));
+				 "have been made and have not been committed."));
         label = gtk_label_new ("");
         gtk_label_set_markup (GTK_LABEL (label), str);
         gtk_misc_set_alignment (GTK_MISC (label), 0., -1);
@@ -1687,7 +1696,7 @@ get_column_data (GnomeDbRawGrid *grid, GdaParameterListGroup *group)
 void
 gnome_db_raw_grid_set_sample_size (GnomeDbRawGrid *grid, gint sample_size)
 {
-	g_return_if_fail (grid && IS_GNOME_DB_RAW_GRID (grid));
+	g_return_if_fail (grid && GNOME_DB_IS_RAW_GRID (grid));
 	g_return_if_fail (grid->priv);
 
 	gda_data_proxy_set_sample_size (grid->priv->proxy, sample_size);
@@ -1702,7 +1711,7 @@ gnome_db_raw_grid_set_sample_size (GnomeDbRawGrid *grid, gint sample_size)
 void
 gnome_db_raw_grid_set_sample_start (GnomeDbRawGrid *grid, gint sample_start)
 {
-	g_return_if_fail (grid && IS_GNOME_DB_RAW_GRID (grid));
+	g_return_if_fail (grid && GNOME_DB_IS_RAW_GRID (grid));
 	g_return_if_fail (grid->priv);
 	
 	gda_data_proxy_set_sample_start (grid->priv->proxy, sample_start);
@@ -1717,7 +1726,7 @@ static GdaDataProxy *
 gnome_db_raw_grid_get_proxy (GnomeDbDataWidget *iface)
 {
 	GnomeDbRawGrid *grid;
-	g_return_val_if_fail (iface && IS_GNOME_DB_RAW_GRID (iface), NULL);
+	g_return_val_if_fail (iface && GNOME_DB_IS_RAW_GRID (iface), NULL);
 	grid = GNOME_DB_RAW_GRID (iface);
 	g_return_val_if_fail (grid->priv, NULL);
 
@@ -1732,7 +1741,7 @@ gnome_db_raw_grid_set_column_editable (GnomeDbDataWidget *iface, gint column, gb
 	ColumnData *column_data;
 	GdaParameterListGroup *group;
 
-	g_return_if_fail (iface && IS_GNOME_DB_RAW_GRID (iface));
+	g_return_if_fail (iface && GNOME_DB_IS_RAW_GRID (iface));
 	grid = GNOME_DB_RAW_GRID (iface);
 	g_return_if_fail (grid->priv);
 	
@@ -1758,28 +1767,43 @@ gnome_db_raw_grid_set_column_editable (GnomeDbDataWidget *iface, gint column, gb
 static void
 gnome_db_raw_grid_show_column_actions (GnomeDbDataWidget *iface, gint column, gboolean show_actions)
 {
-	GdaParameter *param;
-	GdaParameterListGroup *group;
-	ColumnData *cdata;
 	GnomeDbRawGrid *grid;
 
-	g_return_if_fail (iface && IS_GNOME_DB_RAW_GRID (iface));
-	g_return_if_fail (column >= 0);
+	g_return_if_fail (iface && GNOME_DB_IS_RAW_GRID (iface));
 	grid = GNOME_DB_RAW_GRID (iface);
 	g_return_if_fail (grid->priv);
 
-	param = gda_data_model_iter_get_param_for_column (grid->priv->iter, column);
-	g_return_if_fail (param);
-	
-	group = gda_parameter_list_find_group_for_param (GDA_PARAMETER_LIST (grid->priv->iter), param);
-	g_return_if_fail (group);
+	if (column >= 0) {
+		GdaParameter *param;
+		GdaParameterListGroup *group;
+		ColumnData *cdata;
 
-	cdata = get_column_data (grid, group);
-	g_return_if_fail (cdata);
+		/* setting applies only to the @column column */
+		param = gda_data_model_iter_get_param_for_column (grid->priv->iter, column);
+		g_return_if_fail (param);
+		
+		group = gda_parameter_list_find_group_for_param (GDA_PARAMETER_LIST (grid->priv->iter), param);
+		g_return_if_fail (group);
 
-	if (show_actions != cdata->info_shown) {
-		cdata->info_shown = show_actions;
-		g_object_set (G_OBJECT (cdata->info_cell), "visible", cdata->info_shown, NULL);
+		cdata = get_column_data (grid, group);
+		g_return_if_fail (cdata);
+		
+		if (show_actions != cdata->info_shown) {
+			cdata->info_shown = show_actions;
+			g_object_set (G_OBJECT (cdata->info_cell), "visible", cdata->info_shown, NULL);
+		}
+	}
+	else {
+		/* setting applies to all columns */
+		GSList *list;
+		for (list = grid->priv->columns_data; list; list = list->next) {
+			ColumnData *cdata = (ColumnData*)(list->data);
+			if (show_actions != cdata->info_shown) {
+				cdata->info_shown = show_actions;
+				g_object_set (G_OBJECT (cdata->info_cell), "visible", cdata->info_shown, NULL);
+			}
+		}
+		grid->priv->default_show_info_cell = show_actions;
 	}
 }
 
@@ -1792,7 +1816,7 @@ gnome_db_raw_grid_col_set_show (GnomeDbDataWidget *iface, gint column, gboolean
 	GdaParameterListGroup *group;
 	GdaParameter *param;
 
-	g_return_if_fail (iface && IS_GNOME_DB_RAW_GRID (iface));
+	g_return_if_fail (iface && GNOME_DB_IS_RAW_GRID (iface));
 	grid = GNOME_DB_RAW_GRID (iface);
 	g_return_if_fail (grid->priv);
 
@@ -1815,7 +1839,7 @@ gnome_db_raw_grid_get_actions_group (GnomeDbDataWidget *iface)
 {
 	GnomeDbRawGrid *grid;
 	
-	g_return_val_if_fail (iface && IS_GNOME_DB_RAW_GRID (iface), NULL);
+	g_return_val_if_fail (iface && GNOME_DB_IS_RAW_GRID (iface), NULL);
 	grid = GNOME_DB_RAW_GRID (iface);
 	g_return_val_if_fail (grid->priv, NULL);
 
@@ -1827,7 +1851,7 @@ gnome_db_raw_grid_widget_get_data_set (GnomeDbDataWidget *iface)
 {
 	GnomeDbRawGrid *grid;
 	
-	g_return_val_if_fail (iface && IS_GNOME_DB_RAW_GRID (iface), NULL);
+	g_return_val_if_fail (iface && GNOME_DB_IS_RAW_GRID (iface), NULL);
 	grid = GNOME_DB_RAW_GRID (iface);
 	g_return_val_if_fail (grid->priv, NULL);
 
@@ -1839,7 +1863,7 @@ static GdaDataModel *
 gnome_db_raw_grid_widget_get_gda_model (GnomeDbDataWidget *iface)
 {
 	GnomeDbRawGrid *grid;
-	g_return_val_if_fail (iface && IS_GNOME_DB_RAW_GRID (iface), NULL);
+	g_return_val_if_fail (iface && GNOME_DB_IS_RAW_GRID (iface), NULL);
 	grid = GNOME_DB_RAW_GRID (iface);
 	g_return_val_if_fail (grid->priv, NULL);
 
@@ -1878,6 +1902,13 @@ paramlist_public_data_changed_cb (GdaParameterList *paramlist, GnomeDbRawGrid *g
 	init_tree_view (grid);
 }
 
+static void
+paramlist_param_plugin_changed_cb (GdaParameterList *paramlist, GdaParameter *param, GnomeDbRawGrid *grid)
+{
+	/* TODO: be more specific and change only the cell renderer corresponding to @param */
+	paramlist_public_data_changed_cb (paramlist, grid);
+}
+
 static void
 iter_row_changed_cb (GdaDataModelIter *iter, gint row, GnomeDbRawGrid *grid)
 {
@@ -1888,12 +1919,17 @@ iter_row_changed_cb (GdaDataModelIter *iter, gint row, GnomeDbRawGrid *grid)
 	
 	if (row >= 0) {
 		GtkSelectionMode mode;
+		GtkTreeIter treeiter;
 
 		mode = gtk_tree_selection_get_mode (selection);
 		if (mode != GTK_SELECTION_SINGLE)
 			gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
 		path = gtk_tree_path_new_from_indices (row, -1);
-		gtk_tree_selection_select_path (selection, path);
+		if (gtk_tree_model_get_iter (GTK_TREE_MODEL (grid->priv->store), &treeiter, path)) {
+			gtk_tree_selection_select_path (selection, path);
+			gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (grid), path, NULL,
+						      FALSE, 0., 0.);
+		}
 		gtk_tree_path_free (path);
 		if (mode != GTK_SELECTION_SINGLE)
 			gtk_tree_selection_set_mode (selection, mode);
@@ -1923,7 +1959,7 @@ gnome_db_raw_grid_widget_set_gda_model (GnomeDbDataWidget *iface, GdaDataModel *
 {
 	GnomeDbRawGrid *grid;
 
-	g_return_if_fail (iface && IS_GNOME_DB_RAW_GRID (iface));
+	g_return_if_fail (iface && GNOME_DB_IS_RAW_GRID (iface));
 	grid = GNOME_DB_RAW_GRID (iface);
 	g_return_if_fail (grid->priv);
 	
@@ -1960,6 +1996,8 @@ gnome_db_raw_grid_clean (GnomeDbRawGrid *grid)
 	if (grid->priv->iter) {
 		g_signal_handlers_disconnect_by_func (grid->priv->iter,
 						      G_CALLBACK (paramlist_public_data_changed_cb), grid);
+		g_signal_handlers_disconnect_by_func (grid->priv->iter,
+						      G_CALLBACK (paramlist_param_plugin_changed_cb), grid);
 		g_signal_handlers_disconnect_by_func (grid->priv->iter,
 						      G_CALLBACK (iter_row_changed_cb), grid);
 		g_object_unref (grid->priv->iter);
