@@ -51,11 +51,28 @@ enum
 	LAST_SIGNAL
 };
 
+enum
+{
+	P_DICT = 1,
+	P_REFOBJ,
+	P_MODE,
+	P_COLUMNS
+};
+
 static gint gnome_db_selector_signals[LAST_SIGNAL] = { 0, 0 };
 
 /* get a pointer to the parents to be able to call their destructor */
 static GObjectClass *parent_class = NULL;
 
+static void gnome_db_selector_set_property (GObject *object,
+					      guint param_id,
+					      const GValue *value,
+					      GParamSpec *pspec);
+static void gnome_db_selector_get_property (GObject *object,
+					      guint param_id,
+					      GValue *value,
+					      GParamSpec *pspec);
+
 
 GType
 gnome_db_selector_get_type (void)
@@ -108,6 +125,26 @@ gnome_db_selector_class_init (GnomeDbSelectorClass * class)
 	class->selection_changed = NULL;
 	class->row_activated = NULL;
 	object_class->dispose = gnome_db_selector_dispose;
+
+
+	/* Properties */
+	object_class->set_property = gnome_db_selector_set_property;
+	object_class->get_property = gnome_db_selector_get_property;
+
+	g_object_class_install_property (object_class, P_DICT,
+                                         g_param_spec_object ("dict", _("a GdaDict object"), NULL, GDA_TYPE_DICT,
+                                                               G_PARAM_CONSTRUCT_ONLY|G_PARAM_WRITABLE));
+	g_object_class_install_property (object_class, P_REFOBJ,
+                                         g_param_spec_object("ref_obj", _("a GObject object, or NULL if none is required"), NULL, G_TYPE_OBJECT,
+                                                               G_PARAM_CONSTRUCT_ONLY|G_PARAM_WRITABLE));
+	g_object_class_install_property (object_class, P_MODE,
+                                         g_param_spec_uint ("mode", _("an OR'ed value of the possible items to display in the widget"), NULL, 0, -1, 0,
+                                                               G_PARAM_CONSTRUCT_ONLY|G_PARAM_WRITABLE));
+	g_object_class_install_property (object_class, P_COLUMNS,
+                                         g_param_spec_uint("columns", _("an OR'ed value describing which columns will be displayed"), NULL, 0, -1, 0,
+                                                               G_PARAM_CONSTRUCT_ONLY|G_PARAM_WRITABLE));
+
+
 }
 
 static void
@@ -129,6 +166,61 @@ static gboolean gnome_db_selector_initialize (GnomeDbSelector *mgsel, GObject *r
 
 
 static void object_weak_notify (GnomeDbSelector *mgsel, GObject *obj);
+
+
+static void gnome_db_selector_get_property (GObject *object,
+					      guint param_id,
+					      GValue *value,
+					      GParamSpec *pspec)
+{
+
+
+}
+
+
+static void gnome_db_selector_set_property (GObject *object,
+					      guint param_id,
+					      const GValue *value,
+					      GParamSpec *pspec)
+{
+	GnomeDbSelector* mgsel = GNOME_DB_SELECTOR(object);
+	switch(param_id)
+	{
+		case P_DICT:
+		{
+			GdaDict* dict = GDA_DICT(g_value_get_object(value));
+			mgsel->priv->dict = ASSERT_DICT (dict);
+			g_object_weak_ref (G_OBJECT (mgsel->priv->dict),
+			   (GWeakNotify) object_weak_notify, mgsel);
+			break;
+		}
+		case P_REFOBJ:
+		{
+			GObject* ref_obj = G_OBJECT(g_value_get_object(value));
+			mgsel->priv->ref_object = ref_obj;
+			if (gnome_db_selector_initialize (mgsel, ref_obj, FALSE, FALSE) && ref_obj) {
+				/* add a weak ref on that object */
+				g_object_weak_ref (G_OBJECT (mgsel->priv->ref_object),
+					   	(GWeakNotify) object_weak_notify, mgsel);
+			}
+			break;
+		}
+		case P_MODE:
+		{
+			 mgsel->priv->mode = g_value_get_uint(value);
+			break;
+		}
+		case P_COLUMNS:
+		{
+				mgsel->priv->columns = g_value_get_uint(value);
+				break;
+		}	
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+			break;
+	}
+}
+
 /**
  * gnome_db_selector_new
  * @dict: a #GdaDict object
@@ -158,22 +250,7 @@ gnome_db_selector_new (GdaDict *dict, GObject *ref_object, gulong mode, gulong c
 
 	g_return_val_if_fail (!dict || GDA_IS_DICT (dict), NULL);
 		
-	obj = g_object_new (GNOME_DB_TYPE_SELECTOR, NULL);
-	mgsel = GNOME_DB_SELECTOR (obj);
-
-	mgsel->priv->dict = ASSERT_DICT (dict);
-	mgsel->priv->mode = mode;
-	mgsel->priv->columns = columns;
-
-	g_object_weak_ref (G_OBJECT (mgsel->priv->dict),
-			   (GWeakNotify) object_weak_notify, mgsel);
-
-	if (gnome_db_selector_initialize (mgsel, ref_object, FALSE, FALSE) && ref_object) {
-		/* add a weak ref on that object */
-		mgsel->priv->ref_object = ref_object;
-		g_object_weak_ref (G_OBJECT (mgsel->priv->ref_object),
-				   (GWeakNotify) object_weak_notify, mgsel);
-	}
+	obj = g_object_new (GNOME_DB_TYPE_SELECTOR, "dict", dict, "mode", mode, "columns", columns,  "ref_obj", ref_object, NULL);
 
 	return GTK_WIDGET (obj);
 }
@@ -450,6 +527,8 @@ gnome_db_selector_initialize (GnomeDbSelector *mgsel, GObject *ref_object, gbool
 			gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
 							GTK_POLICY_AUTOMATIC,
 							GTK_POLICY_AUTOMATIC);
+        		gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw),
+        						     GTK_SHADOW_IN);
 			gtk_box_pack_start (GTK_BOX (mgsel), sw, TRUE, TRUE, 0);
 		}
 
@@ -2079,3 +2158,4 @@ flat_free_mod_data (Module *module)
 	}
 }
 
+
