@@ -1,6 +1,6 @@
 /* gnome-db-server-operation.c
  *
- * Copyright (C) 2006 Vivien Malerba
+ * Copyright (C) 2006 - 2007 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -49,7 +49,8 @@ static void gnome_db_server_operation_fill (GnomeDbServerOperation *form);
 enum
 {
         PROP_0,
-	PROP_SERVER_OP_OBJ
+	PROP_SERVER_OP_OBJ,
+	PROP_OPT_HEADER
 };
 
 typedef struct _WidgetData {
@@ -66,6 +67,7 @@ struct _GnomeDbServerOperationPriv
 	GSList                 *widget_data; /* list of WidgetData structures */
 	GtkTooltips            *tooltips;
 	GladeXML               *glade;
+	gboolean                opt_header;
 };
 
 WidgetData *widget_data_new (WidgetData *parent, const gchar *path_name);
@@ -194,6 +196,11 @@ gnome_db_server_operation_class_init (GnomeDbServerOperationClass *class)
 							       NULL, GDA_TYPE_SERVER_OPERATION,
 							       G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY |
 							       G_PARAM_READABLE));
+	g_object_class_install_property (object_class, PROP_OPT_HEADER,
+					 g_param_spec_boolean ("opt_header",
+							       _("Request section header to be hidden if there is only one section"),
+							       NULL, FALSE, G_PARAM_CONSTRUCT | G_PARAM_READABLE | 
+							       G_PARAM_WRITABLE));
 }
 
 static void
@@ -206,6 +213,7 @@ gnome_db_server_operation_init (GnomeDbServerOperation * wid)
 	g_object_ref (G_OBJECT (wid->priv->tooltips));
 	gtk_object_sink (GTK_OBJECT (wid->priv->tooltips));
 	wid->priv->glade = NULL;
+	wid->priv->opt_header = FALSE;
 }
 
 
@@ -302,6 +310,9 @@ gnome_db_server_operation_set_property (GObject *object,
 						  G_CALLBACK (sequence_item_remove_cb), form);
 			}
 			break;
+		case PROP_OPT_HEADER:
+			form->priv->opt_header = g_value_get_boolean (value);
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 			break;
@@ -323,6 +334,9 @@ gnome_db_server_operation_get_property (GObject *object,
 		case PROP_SERVER_OP_OBJ:
 			g_value_set_object (value, form->priv->op);
 			break;
+		case PROP_OPT_HEADER:
+			g_value_set_boolean (value, form->priv->opt_header);
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 			break;
@@ -404,7 +418,7 @@ fill_create_widget (GnomeDbServerOperation *form, const gchar *path, gchar **sec
 
 		plist = info_node->plist;
 		plwid = gnome_db_basic_form_new (plist);
-		gnome_db_basic_form_show_entries_actions (GNOME_DB_BASIC_FORM (plwid),
+		gnome_db_basic_form_show_entry_actions (GNOME_DB_BASIC_FORM (plwid),
 							  FALSE);
 	       
 		if (section_str) {
@@ -513,7 +527,7 @@ fill_create_widget (GnomeDbServerOperation *form, const gchar *path, gchar **sec
 		plist = gda_parameter_list_new (list);
 		g_slist_free (list);
 		plwid = gnome_db_basic_form_new (plist);
-		gnome_db_basic_form_show_entries_actions (GNOME_DB_BASIC_FORM (plwid),
+		gnome_db_basic_form_show_entry_actions (GNOME_DB_BASIC_FORM (plwid),
 							  FALSE);
 		/* we don't need plist anymore */
 		g_object_unref (plist);
@@ -740,7 +754,7 @@ gnome_db_server_operation_fill (GnomeDbServerOperation *form)
 			GdaServerOperationNodeStatus status;			
 			GtkWidget *label = NULL, *hbox = NULL;
 
-			if (section_str) {
+			if (! (form->priv->opt_header && (g_strv_length (topnodes) == 1)) && section_str) {
 				GtkWidget *lab;
 				label = gtk_label_new ("");
 				gtk_widget_show (label);
