@@ -28,8 +28,9 @@
  * Data Entry utilities
  *
  */
-GtkWidget*              utility_entry_build_actions_menu      (GObject *obj_data, guint attrs, GCallback function);
-GdkColor **             utility_entry_build_info_colors_array (void);
+GtkWidget              *utility_entry_build_actions_menu      (GObject *obj_data, guint attrs, GCallback function);
+GdkColor              **utility_entry_build_info_colors_array (void);
+gchar                  *utility_markup_title                  (const gchar *title, gboolean optional);
 
 /*
  * Computes attributes and values list from the attributes and values stored in @store and
@@ -43,21 +44,3 @@ guint            utility_proxy_compute_attributes_for_group (GdaParameterListGro
 GList           *utility_proxy_compute_values_for_group     (GdaParameterListGroup *group, 
 							     GnomeDbDataStore *store, GdaDataModelIter *model_iter, 
 							     GtkTreeIter *tree_iter, gboolean model_values);
-
-/*
- *
- * utilities dealing with storing and retreiving GdaDictField's attributes
- * which is a list of comma separated keywords
- *
- */
-gchar           *utility_table_field_attrs_stringify (guint attributes);
-guint            utility_table_field_attrs_parse     (const gchar *str);
-
-
-/*
- *
- * XML Id encoding and decoding
- *
- */
-gchar *utility_build_encoded_id (const gchar *prefix, const gchar *id);
-gchar *utility_build_decoded_id (const gchar *prefix, const gchar *id);
