@@ -3,7 +3,9 @@
 #include <gtk/gtk.h>
 #include <unistd.h>
 #include <string.h>
+#ifdef HAVE_LIBGNOMECANVAS
 #include <libgda/graph/gda-dict-reg-graphs.h>
+#endif
 
 #define SQL_QUERY_ROWS "SELECT c.name, o.creation_date FROM orders o INNER JOIN customers c ON (c.id=o.customer) ORDER BY c.name, o.creation_date"
 #define SQL_QUERY_COLS "SELECT p.name, p.price FROM products p ORDER BY p.name, p.price"
@@ -77,10 +79,16 @@ static void          param_list_param_changed_cb (GdaParameterList *paramlist, G
 /*
  * list of tests' functions
  */
+#ifdef HAVE_LIBGNOMECANVAS
 static GtkWidget *rels_graph_test_make   (MainConfig *config);
 static void       rels_graph_test_clean  (MainConfig *config, GtkWidget *test_widget);
 static gboolean   rels_graph_test_signal (MainConfig *config, GtkWidget *test_widget);
 
+static GtkWidget *query_graph_test_make   (MainConfig *config);
+static void       query_graph_test_clean  (MainConfig *config, GtkWidget *test_widget);
+static gboolean   query_graph_test_signal (MainConfig *config, GtkWidget *test_widget);
+#endif
+
 static GtkWidget *form_grid_test_make_form (MainConfig *config);
 static GtkWidget *form_grid_test_make_grid (MainConfig *config);
 static void       form_grid_test_clean     (MainConfig *config, GtkWidget *test_widget);
@@ -94,10 +102,6 @@ static GtkWidget *selector_test_make   (MainConfig *config);
 static void       selector_test_clean  (MainConfig *config, GtkWidget *test_widget);
 static gboolean   selector_test_signal (MainConfig *config, GtkWidget *test_widget);
 
-static GtkWidget *query_graph_test_make   (MainConfig *config);
-static void       query_graph_test_clean  (MainConfig *config, GtkWidget *test_widget);
-static gboolean   query_graph_test_signal (MainConfig *config, GtkWidget *test_widget);
-
 static GtkWidget *dsn_selector_test_make   (MainConfig *config);
 
 static GtkWidget *editor_test_make   (MainConfig *config);
@@ -124,6 +128,9 @@ static GtkWidget *server_op_test_make  (MainConfig *config);
 static void       server_op_test_clean (MainConfig *config, GtkWidget *test_widget);
 static gboolean   server_op_test_signal (MainConfig *config, GtkWidget *test_widget);
 
+static GtkWidget *transaction_status_test_make (MainConfig *config);
+static gboolean   transaction_status_test_signal (MainConfig *config, GtkWidget *test_widget);
+
 /*
  * tests decalaration
  */
@@ -142,6 +149,7 @@ build_tests (MainConfig *config)
 	test->signal_conn_changed = NULL;
 	list = g_slist_append (list, test);
 
+#ifdef HAVE_LIBGNOMECANVAS
 	/* GnomeDbCanvasDbRelations test */
 	test = g_new0 (ATest, 1);
 	test->test_name = "GnomeDbCanvasDbRelations";
@@ -151,15 +159,6 @@ build_tests (MainConfig *config)
 	test->signal_conn_changed = rels_graph_test_signal;
 	list = g_slist_append (list, test);
 
-	/* GnomeDbSelector test */
-	test = g_new0 (ATest, 1);
-	test->test_name = "GnomeDbSelector";
-	test->test_descr = "";
-	test->make_test_widget = selector_test_make;
-	test->clean_data = selector_test_clean;
-	test->signal_conn_changed = selector_test_signal;
-	list = g_slist_append (list, test);
-
 	/* GnomeDbCanvasQueryStruct test */
 	test = g_new0 (ATest, 1);
 	test->test_name = "GnomeDbCanvasQueryStruct";
@@ -168,6 +167,16 @@ build_tests (MainConfig *config)
 	test->clean_data = query_graph_test_clean;
 	test->signal_conn_changed = query_graph_test_signal;
 	list = g_slist_append (list, test);
+#endif
+
+	/* GnomeDbSelector test */
+	test = g_new0 (ATest, 1);
+	test->test_name = "GnomeDbSelector";
+	test->test_descr = "";
+	test->make_test_widget = selector_test_make;
+	test->clean_data = selector_test_clean;
+	test->signal_conn_changed = selector_test_signal;
+	list = g_slist_append (list, test);
 
 	/* GnomeDbDataSourceSelector test */
 	test = g_new0 (ATest, 1);
@@ -277,6 +286,15 @@ build_tests (MainConfig *config)
 	test->signal_conn_changed = server_op_test_signal;
 	list = g_slist_append (list, test);
 
+	/* GnomeDbTransactionStatus test */
+	test = g_new0 (ATest, 1);
+	test->test_name = "Transaction status";
+	test->test_descr = "";
+	test->make_test_widget = transaction_status_test_make;
+	test->clean_data = NULL;
+	test->signal_conn_changed = transaction_status_test_signal;
+	list = g_slist_append (list, test);
+
 	config->tests = list;
 }
 
@@ -765,20 +783,24 @@ conn_open (MainConfig *config)
 		}
 	}
 	else {
+		gchar *dsn;
+
+		g_object_get (G_OBJECT (config->dict), "dsn", &dsn, NULL);
+		if (!dsn || ! *dsn)
+			use_local_db = TRUE;
+		g_free (dsn);
+
 		if (use_local_db) {
 			/* use a local SQLite database */
 			gchar *dir, *str;
-			if ((dir = getcwd(NULL, 0)) == NULL)
+			if ((dir = getcwd (NULL, 0)) == NULL)
 				exit(1);
-			str = g_build_filename (dir, "TEST_sqlite.db", NULL);
+			str = g_strdup_printf ("DB_DIR=%s;DB_NAME=TEST_sqlite", dir);
 			free (dir);
-			dir = g_strdup_printf ("URI=%s", str);
-			g_free (str);
-			str = dir;
 
-			cnc = gda_client_open_connection_from_string (config->client, "SQLite",
+			cnc = gda_client_open_connection_from_string (config->client, "SQLite", str, 
 								      NULL, NULL,
-								      str, 0, &error);
+								      0, &error);
 			g_free (str);
 			use_local_db = FALSE;
 		}
@@ -1056,7 +1078,7 @@ param_list_param_changed_cb (GdaParameterList *paramlist, GdaParameter *param, g
 
 
 
-
+#ifdef HAVE_LIBGNOMECANVAS
 /*
  * GnomeDbCanvasDbRelations test
  */
@@ -1199,7 +1221,7 @@ query_graph_test_signal (MainConfig *config, GtkWidget *test_widget)
 
 	return TRUE;
 }
-
+#endif
 
 /*
  * GnomeDbForm and GnomeDbGrid tests
@@ -1288,6 +1310,10 @@ form_grid_selected_obj_changed (GnomeDbSelector *mgsel, GObject *obj, TestData3
 			GtkWidget *wid;
 			
 			query_model = get_data_model_from_query (query, gda_object_get_name (GDA_OBJECT (obj)));
+			gda_data_model_query_compute_modification_queries (GDA_DATA_MODEL_QUERY (query_model), 
+									   NULL, 
+									   GDA_DATA_MODEL_QUERY_OPTION_USE_ALL_FIELDS_IF_NO_PK, 
+									   NULL);
 			if (data->is_grid) {
 				GnomeDbRawGrid *raw;
 				wid = gnome_db_grid_new (query_model);
@@ -1299,6 +1325,9 @@ form_grid_selected_obj_changed (GnomeDbSelector *mgsel, GObject *obj, TestData3
 				wid = gnome_db_form_new (query_model);
 				g_object_get (G_OBJECT (wid), "raw_form", &raw, NULL);
 				data_param = gnome_db_data_widget_get_current_data (GNOME_DB_DATA_WIDGET (raw));
+				gnome_db_data_widget_column_show_actions (GNOME_DB_DATA_WIDGET (raw), 0, TRUE);
+				gnome_db_data_widget_set_write_mode (GNOME_DB_DATA_WIDGET (raw), 
+								     GNOME_DB_DATA_WIDGET_WRITE_ON_ROW_CHANGE);
 			}
 			if (query_model)
 				g_object_unref (G_OBJECT (query_model));
@@ -1442,7 +1471,7 @@ cust_forms_grids_test_sel_row_changed_cb (GdaDataModelIter *iter, gint row, Test
 		}
 		else {
 			GtkTreePath *path = gtk_tree_path_new_from_indices (row, -1);
-			gtk_tree_view_set_cursor (data->grid_treeview, path, NULL, FALSE);
+			gtk_tree_view_set_cursor (GTK_TREE_VIEW(data->grid_treeview), path, NULL, FALSE);
 			gtk_tree_path_free (path);
 		}
 	}
@@ -1468,17 +1497,17 @@ cust_forms_grids_test_prepare (MainConfig *config, TestData4 *data)
 	cust_model = gda_data_model_query_new (query);
 	if (!gda_data_model_query_set_modification_query (GDA_DATA_MODEL_QUERY (cust_model),
 							  "UPDATE customers set "
-							  "id=##[:name='+0' :type='gint'], "
-							  "name=##[:name='+1' :type='gchararray'], "
-							  "default_served_by=##[:name='+2' :type='gint'] "
-							  "WHERE id=##[:name='-0' :type='gint']", &error)) {
+							  "id=##/*name:'+0' type:gint*/, "
+							  "name=##/*name:'+1' type:gchararray*/, "
+							  "default_served_by=##/*name:'+2' type:gint*/ "
+							  "WHERE id=##/*name:'-0' type:gint*/", &error)) {
 		g_print ("Error in test code: %s\n",
 			 error && error->message ? error->message : "No detail");
 		g_error_free (error);
 	}
 	if (!gda_data_model_query_set_modification_query (GDA_DATA_MODEL_QUERY (cust_model),
 							  "DELETE from customers "
-							  "WHERE id=##[:name='-0' :type='gint']", &error)) {
+							  "WHERE id=##/*name:'-0' type:gint*/", &error)) {
 		g_print ("Error in test code: %s\n",
 			 error && error->message ? error->message : "No detail");
 		g_error_free (error);
@@ -1486,9 +1515,9 @@ cust_forms_grids_test_prepare (MainConfig *config, TestData4 *data)
 	if (!gda_data_model_query_set_modification_query (GDA_DATA_MODEL_QUERY (cust_model),
 							  "INSERT INTO customers (id, name, default_served_by) "
 							  "values ("
-							  "##[:name='+0' :type='gint'], "
-							  "##[:name='+1' :type='gchararray'], "
-							  "##[:name='+2' :type='gint'])",
+							  "##/*name:'+0' type:gint*/, "
+							  "##/*name:'+1' type:gchararray*/, "
+							  "##/*name:'+2' type:gint*/)",
 							  &error)) {
 		g_print ("Error in test code: %s\n",
 			 error && error->message ? error->message : "No detail");
@@ -1524,7 +1553,7 @@ cust_forms_grids_test_prepare (MainConfig *config, TestData4 *data)
 	g_object_get (G_OBJECT (wid), "raw_grid", &raw_grid, NULL);
 
 	iter = gnome_db_data_widget_get_current_data (GNOME_DB_DATA_WIDGET (raw_grid));
-	data->grid_treeview = raw_grid;
+	data->grid_treeview = GTK_WIDGET(raw_grid);
 	data->grid_iter = iter;
 	param = g_slist_nth_data (GDA_PARAMETER_LIST (iter)->parameters, 2);
 	if (!gda_parameter_restrict_values (param, sr_model, 0, &error)) {
@@ -1552,7 +1581,7 @@ cust_forms_grids_test_prepare (MainConfig *config, TestData4 *data)
 	g_object_get (G_OBJECT (wid), "raw_form", &raw_form, NULL);
 
 	iter = gnome_db_data_widget_get_current_data (GNOME_DB_DATA_WIDGET (raw_form));
-	/* gnome_db_basic_form_show_entries_actions (GNOME_DB_BASIC_FORM (raw_form), TRUE); */
+	/* gnome_db_basic_form_show_entry_actions (GNOME_DB_BASIC_FORM (raw_form), TRUE); */
 	data->form_iter = iter;
 	param = g_slist_nth_data (GDA_PARAMETER_LIST (iter)->parameters, 2);
 	if (!gda_parameter_restrict_values (param, sr_model, 0, &error)) {
@@ -2822,7 +2851,7 @@ server_op_test_do_dump (GtkButton *button, TestData10 *data)
 {
 	xmlNodePtr node;
 
-	if (!data->op || !data->op_form || ! IS_GNOME_DB_SERVER_OPERATION (data->op_form)) {
+	if (!data->op || !data->op_form || ! GNOME_DB_IS_SERVER_OPERATION (data->op_form)) {
 		g_print ("No form!\n");
 		return;
 	}
@@ -2853,7 +2882,7 @@ server_op_test_do_load (GtkButton *button, TestData10 *data)
 	GError *error = NULL;
 	gchar *filename;
 
-	if (!data->op || !data->op_form || ! IS_GNOME_DB_SERVER_OPERATION (data->op_form)) {
+	if (!data->op || !data->op_form || ! GNOME_DB_IS_SERVER_OPERATION (data->op_form)) {
 		g_print ("No form!\n");
 		return;
 	}
@@ -2972,3 +3001,110 @@ server_op_test_signal (MainConfig *config, GtkWidget *test_widget)
 
 	return TRUE;
 }
+
+/*
+ *
+ * Transaction Status test
+ *
+ */
+typedef struct {
+	MainConfig              *config;
+	GtkWidget               *form_vbox;
+	GtkWidget               *status;
+	GtkWidget               *console;
+} TestData11;
+
+static gchar *transaction_status_test_sql_entered_cb (GnomeDbSqlConsole *console, const gchar *sql, TestData11 *data);
+
+
+static GtkWidget *
+transaction_status_test_make (MainConfig *config)
+{
+	GtkWidget *vbox, *label;
+	GtkWidget *sw, *console;
+	TestData11 *data;
+
+	/* private test data */
+	data = g_new0 (TestData11, 1);
+	data->config = config;
+	data->form_vbox = gtk_vbox_new (FALSE, 0);
+
+	vbox = gtk_vbox_new (FALSE, 0);
+	g_object_set_data (G_OBJECT (vbox), "private_data", data);
+
+	/* tested widget */
+	label = gtk_label_new ("<b>GnomeDbTransactionStatus widget</b>");
+	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+	gtk_misc_set_alignment (GTK_MISC (label), 0., -1);
+	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
+	gtk_widget_show (label);
+
+	gtk_box_pack_start (GTK_BOX (vbox), data->form_vbox, TRUE, TRUE, 0);
+	gtk_widget_show (data->form_vbox);
+	transaction_status_test_signal (config, vbox);
+
+	/* console */
+	label = gtk_label_new ("<b>Console to enter transaction orders</b>\nwhich are not executed by the connection!!!");
+	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+	gtk_misc_set_alignment (GTK_MISC (label), 0., -1);
+	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
+	gtk_widget_show (label);
+
+	sw = gtk_scrolled_window_new (NULL, NULL);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
+					GTK_POLICY_AUTOMATIC,
+					GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_IN);	
+	
+	console = gnome_db_sql_console_new (NULL, _("SQL Console (type \\? + ENTER for help)\n"));
+	gtk_container_add (GTK_CONTAINER (sw), console);
+	gtk_widget_show (console);
+	gtk_box_pack_start (GTK_BOX (vbox), sw, TRUE, TRUE, 0);
+
+	g_signal_connect (G_OBJECT (console), "sql_entered",
+			  G_CALLBACK (transaction_status_test_sql_entered_cb), data);
+
+	return vbox;
+}
+
+static gboolean
+transaction_status_test_signal (MainConfig *config, GtkWidget *test_widget)
+{
+	TestData11 *data = g_object_get_data (G_OBJECT (test_widget), "private_data");
+	GtkWidget *status, *label;
+
+	if (data->status)
+		gtk_widget_destroy (data->status);
+
+	if (gda_dict_get_connection (data->config->dict)) {
+		status = gnome_db_transaction_status_new (gda_dict_get_connection (data->config->dict));
+		gtk_box_pack_start (GTK_BOX (data->form_vbox), status, TRUE, TRUE, 0);
+		gtk_widget_show (status);
+		data->status = status;
+	}
+	else {
+		label = gtk_label_new ("No GdaConnection");
+		gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+		gtk_misc_set_alignment (GTK_MISC (label), 0., -1);
+		gtk_box_pack_start (GTK_BOX (data->form_vbox), label, TRUE, TRUE, 0);
+		gtk_widget_show (label);
+		data->status = label;
+	}
+	return TRUE;
+}
+
+static gchar *
+transaction_status_test_sql_entered_cb (GnomeDbSqlConsole *console, const gchar *sql, TestData11 *data)
+{
+	GdaConnection *cnc;
+
+	cnc = gda_dict_get_connection (data->config->dict);
+	if (cnc) {
+		gda_connection_internal_treat_sql (cnc, sql, NULL);
+		return g_strdup ("WARNING: this SQL is not run by the connection,"
+				 "\nbut just used as a shortcut to stimulate GdaConnection's\n"
+				 "transaction status tracking.");
+	}
+	else
+		return g_strdup ("No connection: nothing done.");
+}
